@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -26,7 +26,7 @@
 #include <qlayout.h>
 #include <qtextstream.h>
 #include <kapp.h>
-#if (KDE_VERSION_MAJOR < 3) || (KDE_VERSION_MINOR < 9)
+#if KDE_VERSION_MAJOR < 3
 #include <qmultilineedit.h>
 #endif
 #include <klocale.h>
@@ -107,11 +107,7 @@ ArrayDlg::ArrayDlg(QWidget* _parent, KplDoc* model, ArrayItem* _ad) :
   colData->setMinimumWidth(50);
   setSpinBoxes(ad);
   Utils::setSize(this, "ArrayDialog");
-#if KDE_VERSION == 303
-  connect(this, SIGNAL(helpClicked()), SLOT(slotHelp2()));
-#else
   setHelp("SEC-ARRAY");
-#endif
   connect(internal, SIGNAL(toggled(bool)), SLOT(slotInternal(bool)));
   connect(err, SIGNAL(toggled(bool)), ie, SLOT(setEnabled(bool)));
   connect(iStart, SIGNAL(valueChanged(int)), SLOT(slotStartChanged(int)));
@@ -292,7 +288,7 @@ void ArrayDlg::slotEdit()
     for (int j = 0; j < src->ncols; j++)
       t << m->number(src->x[j][i])
         << (j < (src->ncols - 1) ? m->separator() : QString("\n"));
-#if (KDE_VERSION_MAJOR > 2) || (KDE_VERSION_MINOR > 8)
+#if KDE_VERSION_MAJOR > 2
   EditDlg dlg(this, &buf, m->options()->prec + 4);
 #else
   int sav = QMultiLineEdit::defaultTabStop();
@@ -305,7 +301,7 @@ void ArrayDlg::slotEdit()
     adt = new ArrayItem;
     readData(true);
   }
-#if (KDE_VERSION_MAJOR < 3) && (KDE_VERSION_MINOR < 9)
+#if KDE_VERSION_MAJOR < 3
   QMultiLineEdit::setDefaultTabStop(sav);
 #endif
 }
@@ -352,11 +348,3 @@ void ArrayDlg::slotApply()
 {
   getValues(false);
 }
-
-void ArrayDlg::slotHelp2()
-{
-#if KDE_VERSION == 303
-  kapp->startServiceByDesktopName("konqueror", QString("help:/kpl/array.html"),
-                                  0, 0, 0, "", true);
-#endif
-}
