@@ -2,7 +2,7 @@
                           arrowdlg.cpp  -  description
                              -------------------
     begin                : Sat Apr 14 2001
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -18,7 +18,6 @@
 #include <qlayout.h>
 #include <qlabel.h>
 #include <klocale.h>
-#include <kapp.h>
 #include "arrowdlg.h"
 #include "arrowitem.h"
 #include "kpldoubleedit.h"
@@ -28,9 +27,6 @@ ArrowDlg::ArrowDlg(QWidget* _parent, KplDoc* model, ArrowItem* ad0, int nrows) :
 {
   initPolarEntries(plainPage(), ad, grid, &eDir, &eLen);
   initEntries(1);
-#if KDE_VERSION == 303
-  connect(this, SIGNAL(helpClicked()), SLOT(slotHelp2()));
-#endif
 }
 
 ArrowDlg::~ArrowDlg()
@@ -67,11 +63,3 @@ void ArrowDlg::slotApply()
 {
   getValues(false);
 }
-
-void ArrowDlg::slotHelp2()
-{
-#if KDE_VERSION == 303
-  kapp->startServiceByDesktopName("konqueror", QString("help:/kpl/arrow.html"),
-                                  0, 0, 0, "", true);
-#endif
-}
