@@ -2,7 +2,7 @@
                           arrowdlg.h  -  description
                              -------------------
     begin                : Sat Apr 14 2001
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -66,8 +66,6 @@ protected slots:
   virtual void slotOk();
   /** Applies settings without leaving the dialog. */
   virtual void slotApply();
-  /** Displays help for the arrow settings dialog. */
-  void slotHelp2();
 };
 
 #endif
