@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -28,7 +28,6 @@
 #include <qlabel.h>
 #include <qlayout.h>
 #include <klocale.h>
-#include <kapp.h>
 #include <kglobal.h>
 #include "autodlg.h"
 #include "edittextdlg.h"
@@ -124,11 +123,7 @@ AutoDlg::AutoDlg(QWidget* _parent, KplDoc* m0) :
   grid->addWidget(autoFit = new QCheckBox(i18n("Autofit"), g), 2, 5);
   autoFit->setChecked(a->autoFit);
   Utils::setSize(this, "AutoPlotDialog");
-#if KDE_VERSION == 303
-  connect(this, SIGNAL(helpClicked()), SLOT(slotHelp2()));
-#else
   setHelp("SEC-AUTOPLOT");
-#endif
   connect(autohPath, SIGNAL(toggled(bool)), SLOT(disableHeading(bool)));
   connect(logX, SIGNAL(toggled(bool)), SLOT(slotLogToggled(bool)));
   connect(logY, SIGNAL(toggled(bool)), SLOT(slotLogToggled(bool)));
@@ -206,12 +201,3 @@ void AutoDlg::slotOk()
   m->setOptions(a);
   accept();
 }
-
-void AutoDlg::slotHelp2()
-{
-#if KDE_VERSION == 303
-  kapp->startServiceByDesktopName("konqueror",
-                                  QString("help:/kpl/autoplot.html"),
-                                  0, 0, 0, "", true);
-#endif
-}
