@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -78,8 +78,6 @@ protected slots:
   void slotNormToggled(bool state);
   /** Applies settings and leaves the dialog. */
   virtual void slotOk();
-  /** Displays help for the autoplot settings dialog. */
-  void slotHelp2();
 };
 
 #endif
