@@ -2,7 +2,7 @@
                           autofitdlg.cpp  -  description
                              -------------------
     begin                : Sat Jun 5 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -24,6 +24,7 @@
 #include <qfileinfo.h>
 #include <qlayout.h>
 #include <qtimer.h>
+#include <qregexp.h>
 #include <kapp.h>
 #include <klocale.h>
 #include <kcolorbtn.h>
@@ -58,30 +59,62 @@ EditFitParameterDlg::EditFitParameterDlg(QWidget* _parent, KplDoc* m,
                                       spacingHint());
   vbox->addWidget(g);
   QString s;
+  char frm = m->options()->format;
+  int prec = m->options()->prec;
+  int w = 0;
   for (int i = 0; i < KPL_NPMAX; i++) {
     int ix = 3 * (i / 10);
     int iy = i % 10;
     grid->addWidget(enFit[i] = new QCheckBox(s.sprintf("p%i", i), g), iy, ix);
     enFit[i]->setChecked(bFit[i]);
-    grid->addWidget(par[i] = new QLineEdit(m->number(p[i]), g), iy, ix + 1);
-    par[i]->setMaximumWidth(80);
+    grid->addWidget(par[i] = new KplDoubleEdit(p[i], g, frm, prec), iy,
+                    ix + 1);
+    if (!i)
+      w = par[0]->fontMetrics().width(m->number(-1.0e-123 / 3.0)) + 3;
+    par[i]->setMinimumWidth(w);
   }
   for (int i = 0; i < ((KPL_NPMAX - 1) / 10); i++)
     grid->addItem(new QSpacerItem(20, 10), 0, 3 * i + 2);
   if (m->options()->showSource) {
     QFileInfo fi(file);
-    int pp = func.find("__");
-    s = fi.dirPath(true) + "/" + fi.baseName() + ((pp != -1) ? ".cpp" : ".c");
-    QFile f(s);
-    if (f.open(IO_ReadOnly)) {
+#if KDE_VERSION_MAJOR > 2
+    QRegExp rx2("\\S+__FdPCd");
+    QRegExp rx3("_Z\\d+\\S+dPKd");
+    int pp2 = rx2.search(func);
+    int pp3 = rx3.search(func);
+#else
+    QRegExp rx2("[^\\s]+__FdPCd");
+    QRegExp rx3("_Z\\d+[^\\s]+dPKd");
+    int l2, l3;
+    int pp2 = rx2.match(func, 0, &l2);
+    int pp3 = rx3.match(func, 0, &l3);
+#endif
+    s = fi.dirPath(true) + "/" + fi.baseName();
+    bool guessC = pp2 && pp3;
+    QFile f(s + (guessC ? ".c" : ".cpp"));
+    bool open = f.open(IO_ReadOnly);
+    if (!open) {
+      f.setName(s + (guessC ? ".cpp" : ".c"));
+      open = f.open(IO_ReadOnly);
+    }
+    if (open) {
       SourceWidget *sw = new SourceWidget(frame, &f);
       hbox->addWidget(sw, 1);
       sw->setMinimumWidth(400);
-      if (pp != -1) {
-        s = func;
-        sw->highlight(s.left(pp));
-      } else
-        sw->highlight(func);
+      if (!pp2)
+#if KDE_VERSION_MAJOR > 2
+        sw->highlight(func.left(rx2.matchedLength() - 7));
+      else
+        if (!pp3)
+          sw->highlight(func.mid(3, rx3.matchedLength() - 7));
+#else
+        sw->highlight(func.left(l2 - 7));
+      else
+        if (!pp3)
+          sw->highlight(func.mid(3, l3 - 7));
+#endif
+        else
+          sw->highlight(func);
       QTimer::singleShot(0, sw, SLOT(slotHighlight()));
     }
   }
@@ -93,20 +126,10 @@ EditFitParameterDlg::~EditFitParameterDlg()
 
 void EditFitParameterDlg::slotOk()
 {
-  QString s;
-  double pt[KPL_NPMAX];
-  bool valid = true;
   for (int i = 0; i < KPL_NPMAX; i++) {
-    s = par[i]->text();
-    pt[i] = s.toDouble(&valid);
-    if (!valid) {
-      KMessageBox::sorry(this, s.sprintf(i18n("invalid parameter %i"), i));
-      return;
-    }
-  }
-  memcpy(p, pt, KPL_NPMAX * sizeof(double));
-  for (int i = 0; i < KPL_NPMAX; i++)
+    p[i] = par[i]->value();
     bFit[i] = enFit[i]->isChecked();
+  }
   accept();
 }
 
@@ -157,7 +180,7 @@ AutoFitDlg::AutoFitDlg(QWidget* _parent, KplDoc* m0) :
   grid->addWidget(sItmax = new KplSpinBox(1, 200, 1, g), 1, 1);
   sItmax->setValue(aut->fitMaxIt);
   grid->addWidget(new QLabel(i18n("Tolerance"), g), 1, 3);
-  grid->addWidget(eTol = new KplDoubleEdit(aut->fitTol, 0.0, 1.0, g, "%.6lg"),
+  grid->addWidget(eTol = new KplDoubleEdit(aut->fitTol, 0.0, 1.0, g, 'g', 6),
                   1, 4);
   grid->addLayout(hbox = new QHBoxLayout(), 2, 0);
   hbox->addWidget(new QLabel(i18n("Symbol"), g));
@@ -175,11 +198,7 @@ AutoFitDlg::AutoFitDlg(QWidget* _parent, KplDoc* m0) :
   vbox2->addWidget(follow = new QCheckBox(i18n("Follow parameters"), g));
   follow->setChecked(aut->fitFollow);
   resize(minimumSize());
-#if KDE_VERSION == 303
-  connect(this, SIGNAL(helpClicked()), SLOT(slotHelp2()));
-#else
   setHelp("SEC-AUTOFIT");
-#endif
   connect(errCol, SIGNAL(toggled(bool)), SLOT(disableErrMod(bool)));
   connect(nonLin, SIGNAL(toggled(bool)), SLOT(enableNonLin(bool)));
   disableErrMod(aut->err.fitErrCol);
@@ -261,12 +280,3 @@ void AutoFitDlg::slotOk()
   m->setOptions(aut);
   accept();
 }
-
-void AutoFitDlg::slotHelp2()
-{
-#if KDE_VERSION == 303
-  kapp->startServiceByDesktopName("konqueror",
-                                  QString("help:/kpl/autofit.html"),
-                                  0, 0, 0, "", true);
-#endif
-}
