@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -24,7 +24,6 @@
 #include <qlabel.h>
 #include <qlayout.h>
 #include <klocale.h>
-#include <kapp.h>
 #include <kcolorbtn.h>
 #include <kglobal.h>
 #include "basicdlg.h"
@@ -103,11 +102,7 @@ BasicDlg::BasicDlg(QWidget* _parent, Kpl::AutoStruct* bs) :
   sep->setCurrentItem(b->iSep);
   grid->addWidget(new QLabel(sep, i18n("&Separator"), g), 2, 0);
   Utils::setSize(this, "BasicDialog");
-#if KDE_VERSION == 303
-  connect(this, SIGNAL(helpClicked()), SLOT(slotHelp2()));
-#else
   setHelp("SEC-BASIC");
-#endif
   connect(format, SIGNAL(activated(int)), SLOT(slotFormatChanged(int)));
 }
 
@@ -139,11 +134,3 @@ void BasicDlg::slotOk()
   b->iSep = sep->currentItem();
   accept();
 }
-
-void BasicDlg::slotHelp2()
-{
-#if KDE_VERSION == 303
-  kapp->startServiceByDesktopName("konqueror", QString("help:/kpl/basic.html"),
-                                  0, 0, 0, "", true);
-#endif
-}
