@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -66,8 +66,6 @@ protected slots:
   void slotFormatChanged(int i);
   /** Applies settings and leaves the dialog. */
   virtual void slotOk();
-  /** Displays help for the basic settings dialog. */
-  void slotHelp2();
 };
 
 #endif
