@@ -2,7 +2,7 @@
                           decodlg.cpp  -  description
                              -------------------
     begin                : Fri Apr 20 2001
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -31,9 +31,7 @@ DecoDlg::DecoDlg(QWidget* _parent, QString caption, QString anchor,
  m(model), it(it0)
 {
   grid = new QGridLayout(plainPage(), nrows, 7, 0, spacingHint());
-#if KDE_VERSION != 303
   setHelp(anchor);
-#endif
   resize(minimumSize());
 }
 
