@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -163,11 +163,5 @@ void EditTextDlg::slotOk()
 
 void EditTextDlg::slotHelp()
 {
-#if KDE_VERSION == 303
-  kapp->startServiceByDesktopName("konqueror",
-                                  QString("help:/kpl/edit-text.html"),
-                                  0, 0, 0, "", true);
-#else
   kapp->invokeHelp("SEC-EDIT-TEXT");
-#endif
 }
