@@ -2,7 +2,7 @@
                           fitdlg.cpp  -  description
                              -------------------
     begin                : Tue May 25 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -17,7 +17,6 @@
 
 #include <stdlib.h>
 #include <math.h>
-#include <dlfcn.h>
 #include <qgroupbox.h>
 #include <qfileinfo.h>
 #include <qlistbox.h>
@@ -29,6 +28,7 @@
 #include <qlayout.h>
 #include <qtable.h>
 #include <qtimer.h>
+#include <qregexp.h>
 #include <kapp.h>
 #include <klocale.h>
 #include <kurl.h>
@@ -100,11 +100,7 @@ ErrModDlg::ErrModDlg(QWidget* _parent, KplDoc* model,
   hbox->addWidget(func = new QLineEdit(err->errModName, frame));
   hbox->addWidget(b = new QPushButton("...", frame));
   b->setFixedWidth(28);
-#if KDE_VERSION == 303
-  connect(this, SIGNAL(helpClicked()), SLOT(slotHelp2()));
-#else
   setHelp("ERRORMODEL");
-#endif
   connect(b, SIGNAL(clicked()), SLOT(slotFunc()));
   grid->addWidget(new QLabel(i18n("Parameter"), frame), 2, 0);
   grid->addLayout(hbox = new QHBoxLayout(), 2, 1);
@@ -159,24 +155,15 @@ void ErrModDlg::slotOk()
 {
   errt->errModPath = fileName->text();
   errt->errModName = func->text();
-  void *hErrMod = 0;
+  lt_dlhandle hErrMod = 0;
   double (*fkt)(double, const double *);
   if (FunItem::getFuncAddr(errt->errModPath, errt->errModName, &hErrMod, &fkt))
     return;
-  dlclose(hErrMod);
+  lt_dlclose(hErrMod);
   *err = *errt;
   accept();
 }
 
-void ErrModDlg::slotHelp2()
-{
-#if KDE_VERSION == 303
-  kapp->startServiceByDesktopName("konqueror",
-                                  QString("help:/kpl/fit.html#errormodel"),
-                                  0, 0, 0, "", true);
-#endif
-}
-
 FitDlg::FitDlg(QWidget* _parent, KplDoc* model, QList<ArrayItem>* ad0,
                QList<FunItem>* fd0, int mode) :
  KDialogBase(Plain, i18n("Parameter fit"),
@@ -235,21 +222,26 @@ FitDlg::FitDlg(QWidget* _parent, KplDoc* model, QList<ArrayItem>* ad0,
                                         5 * nGr - 1);
     for (i = 1; i < nGr; i++)
       grid->addItem(new QSpacerItem(20, 10), 0, 4 * i);
+    char frm = m->options()->format;
+    int prec = m->options()->prec;
+    int w = 0;
+    QString s0 = m->number(0.0);
     for (i = 0; i < KPL_NPMAX; i++) {
       int ix = 5 * (i / 10);
       int iy = i % 10;
       grid->addWidget(enFit[i] = new QCheckBox(s.sprintf("p%i", i), g, "f"),
                       iy, ix);
       enFit[i]->setChecked(aut->fitPar[i]);
-      grid->addWidget(par[i] = new QLineEdit(m->number(m->pLast[i]), g),
+      grid->addWidget(par[i] = new KplDoubleEdit(m->pLast[i], g, frm, prec),
                       iy, ix + 1);
-      par[i]->setMaximumWidth(80);
+      if (!i)
+        w = QMAX(80, par[0]->fontMetrics().width(m->number(-1.0e-123 / 3.0)) +
+                                                 3);
+      par[i]->setFixedWidth(w);
       grid->addWidget(new QLabel("\261", g), iy, ix + 2);
-      grid->addWidget(epar[i] = new QLabel("0", g), iy, ix + 3);
+      grid->addWidget(epar[i] = new QLabel(s0, g), iy, ix + 3);
       epar[i]->setFrameStyle(QFrame::Panel | QFrame::Sunken);
-      epar[i]->setMaximumWidth(100);
-      epar[i]->setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding,
-                                         QSizePolicy::Fixed));
+      epar[i]->setFixedWidth(w);
     }
     QHBoxLayout* hbox2 = new QHBoxLayout(vbox2, spacingHint());
     hbox2->addWidget(nonLin = new QCheckBox(i18n("Nonlinear fit"), g));
@@ -286,7 +278,7 @@ FitDlg::FitDlg(QWidget* _parent, KplDoc* model, QList<ArrayItem>* ad0,
     hbox2->addItem(new QSpacerItem(10, 10, QSizePolicy::Expanding));
     hbox2->addWidget(new QLabel(i18n("Tolerance"), frame));
     hbox2->addWidget(eTol = new KplDoubleEdit(aut->fitTol, 0.0, 1.0, frame,
-                                              "%.6lg"));
+                                              'g', 6));
     widgetList.append(eTol);
     vbox->addWidget(results = new QListBox(frame));
     results->setMinimumHeight(40);
@@ -298,11 +290,7 @@ FitDlg::FitDlg(QWidget* _parent, KplDoc* model, QList<ArrayItem>* ad0,
       hbox->addWidget(sw = new SourceWidget(frame, 0), 1);
       sw->setMinimumWidth(200);
     }
-#if KDE_VERSION == 303
-    connect(this, SIGNAL(helpClicked()), SLOT(slotHelp2()));
-#else
     setHelp("SEC-FIT");
-#endif
     connect(nonLin, SIGNAL(toggled(bool)), SLOT(enableNonLin(bool)));
     connect(errCol, SIGNAL(toggled(bool)), SLOT(errColToggled(bool)));
     connect(sArr, SIGNAL(valueChanged(int)), SLOT(updArray(int)));
@@ -369,7 +357,7 @@ void FitDlg::slotGetParameter()
 {
   Utils::getPar(this, m->pLast, m);
   for (int i = 0; i < KPL_NPMAX; i++) {
-    par[i]->setText(m->number(m->pLast[i]));
+    par[i]->setValue(m->pLast[i]);
     m->pErr[i] = 0.0;
     epar[i]->setText("0");
   }
@@ -404,17 +392,42 @@ void FitDlg::updArray(int i)
   if (m->options()->showSource) {
     FunItem* ff = fd->at(i);
     QFileInfo fi(ff->pathy.path());
-    int pp = ff->namey.find("__");
-    QString s = fi.dirPath(true) + "/" + fi.baseName() +
-      ((pp != -1) ? ".cpp" : ".c");
-    QFile f(s);
-    if (f.open(IO_ReadOnly)) {
+#if KDE_VERSION_MAJOR > 2
+    QRegExp rx2("\\S+__FdPCd");
+    QRegExp rx3("_Z\\d+\\S+dPKd");
+    int pp2 = rx2.search(ff->namey);
+    int pp3 = rx3.search(ff->namey);
+#else
+    QRegExp rx2("[^\\s]+__FdPCd");
+    QRegExp rx3("_Z\\d+[^\\s]+dPKd");
+    int l2, l3;
+    int pp2 = rx2.match(ff->namey, 0, &l2);
+    int pp3 = rx3.match(ff->namey, 0, &l3);
+#endif
+    QString s = fi.dirPath(true) + "/" + fi.baseName();
+    bool guessC = pp2 && pp3;
+    QFile f(s + (guessC ? ".c" : ".cpp"));
+    bool open = f.open(IO_ReadOnly);
+    if (!open) {
+      f.setName(s + (guessC ? ".cpp" : ".c"));
+      open = f.open(IO_ReadOnly);
+    }
+    if (open) {
       sw->fill(&f);
-      if (pp != -1) {
-        s = ff->namey;
-        sw->highlight(s.left(pp));
-      } else
-        sw->highlight(ff->namey);
+      if (!pp2)
+#if KDE_VERSION_MAJOR > 2
+        sw->highlight(ff->namey.left(rx2.matchedLength() - 7));
+      else
+        if (!pp3)
+          sw->highlight(ff->namey.mid(3, rx3.matchedLength() - 7));
+#else
+        sw->highlight(ff->namey.left(l2 - 7));
+      else
+        if (!pp3)
+          sw->highlight(ff->namey.mid(3, l3 - 7));
+#endif
+        else
+          sw->highlight(ff->namey);
     }
   }
 }
@@ -437,15 +450,6 @@ void FitDlg::slotApply()
   getValues(false);
 }
 
-
-void FitDlg::slotHelp2()
-{
-#if KDE_VERSION == 303
-  kapp->startServiceByDesktopName("konqueror", QString("help:/kpl/fit.html"),
-                                  0, 0, 0, "", true);
-#endif
-}
-
 void FitDlg::slotUser1()
 {
   fit();
@@ -471,15 +475,9 @@ void FitDlg::fit()
     nLin = aut->fitNonLin;
   np = 0;
   int i;
-  bool valid;
-  QString s;
   for (i = 0; i < KPL_NPMAX; i++) {
     if (dlgMode & ShowDlg) {
-      m->pLast[i] = par[i]->text().toDouble(&valid);
-      if (!valid) {
-        KMessageBox::sorry(this, s.sprintf(i18n("invalid parameter %i"), i));
-        return;
-      }
+      m->pLast[i] = par[i]->value();
       aut->fitPar[i] = enFit[i]->isChecked();
     }
     if (aut->fitPar[i])
@@ -504,20 +502,22 @@ void FitDlg::fit()
         lm->sig[j++] = a->x[a->ie][a->istart + i];
     } else {
       double (*fktErrMod)(double, const double*);
-      void* hErrMod;
+      lt_dlhandle hErrMod;
       if (FunItem::getFuncAddr(err[k].errModPath, err[k].errModName, &hErrMod,
                                &fktErrMod))
         return;
       for (i = 0; i < a->n; i++)
         lm->sig[j++] = fktErrMod(a->x[a->iy][a->istart + i], err[k].pErrMod);
-      dlclose(hErrMod);
+      lt_dlclose(hErrMod);
     }
   }
   lm->ad = ad;
   lm->fd = fd;
   lm->bFit = aut->fitPar;
   lm->p = m->pLast;
-  double* wa = (double*) calloc((6 + np + n) * np + n, sizeof(double));
+  int wadim = (6 + np + n) * np + n;
+  double* wa = new double[wadim];
+  memset(wa, 0, wadim * sizeof(double));
   double* guess = wa + 3 * np + n;
   double* diag = guess + np;
   double* fjac = diag + np;
@@ -538,6 +538,7 @@ void FitDlg::fit()
   kapp->processEvents();
   bool aborted = lm->userBreak = false;
   running = true;
+  QString s;
   if (nLin) {
     int info = 0;
     int nfev;
@@ -630,7 +631,7 @@ void FitDlg::fit()
       } else
         m->pErr[i] = 0.0;
       if (dlgMode & ShowDlg) {
-        par[i]->setText(m->number(m->pLast[i]));
+        par[i]->setValue(m->pLast[i]);
         epar[i]->setText(m->number(m->pErr[i]));
       }
       if (dlgMode & Follow)
@@ -663,7 +664,7 @@ void FitDlg::fit()
       enFit[i]->setEnabled(true);
     }
   }
-  free(wa);
+  delete [] wa;
 }
 
 void FitDlg::slotErrMod()
