@@ -2,7 +2,7 @@
                           fitdlg.h  -  description
                              -------------------
     begin                : Tue May 25 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -94,8 +94,6 @@ protected slots:
   void slotSaveParameter();
   /** Accepts changes and leaves the dialog. */
   virtual void slotOk();
-  /** Displays help for the errormode dialog. */
-  void slotHelp2();
 };
 
 /**
@@ -142,7 +140,7 @@ protected:
   LMFit* lm;
   QListBox* results;
   KplDoubleEdit* eTol;
-  QLineEdit* par[KPL_NPMAX];
+  KplDoubleEdit* par[KPL_NPMAX];
   QLabel* lArr;
   QLabel* epar[KPL_NPMAX];
   QCheckBox* enFit[KPL_NPMAX];
@@ -183,8 +181,6 @@ protected slots:
   virtual void slotApply();
   /** Accepts changes and leaves the dialog. */
   virtual void slotOk();
-  /** Displays help for the fit dialog. */
-  void slotHelp2();
   /** Stops fitting or leaves the dialog without applying the changes. */
   virtual void slotCancel();
   /** Displays the dialog for setting the calculation of error bars. */
