@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -27,7 +27,6 @@
 #include <qlabel.h>
 #include <qlayout.h>
 #include <klocale.h>
-#include <kapp.h>
 #include <kcolorbtn.h>
 #include <kglobal.h>
 #include <kconfig.h>
@@ -81,23 +80,23 @@ FrameDlg::FrameDlg(QWidget* _parent, KplDoc* model, int it) :
   grid2->addWidget(new QLabel("xmin", g), 0, 0);
   grid2->addWidget(exMin = new KplDoubleEdit(fd.xmi, fd.logx ?
                                              1.0e-300 : -1.0e300,
-                                             1.0e300, g, "%.6lg"), 0, 1);
+                                             1.0e300, g, 'g', 6), 0, 1);
   grid2->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding), 0, 2);
   grid2->addWidget(new QLabel("xmax", g), 0, 3);
   grid2->addWidget(exMax = new KplDoubleEdit(fd.xma, fd.logx ?
                                              1.0e-300 : -1.0e300,
-                                             1.0e300, g, "%.6lg"), 0, 4);
+                                             1.0e300, g, 'g', 6), 0, 4);
   grid2->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding), 0, 5);
   grid2->addWidget(logX = new QCheckBox("log", g), 0, 6);
   logX->setChecked(fd.logx);
   grid2->addWidget(new QLabel("ymin", g), 1, 0);
   grid2->addWidget(eyMin = new KplDoubleEdit(fd.ymi, fd.logy ?
                                              1.0e-300 : -1.0e300,
-                                             1.0e300, g, "%.6lg"), 1, 1);
+                                             1.0e300, g, 'g', 6), 1, 1);
   grid2->addWidget(new QLabel("ymax", g), 1, 3);
   grid2->addWidget(eyMax = new KplDoubleEdit(fd.yma, fd.logy ?
                                              1.0e-300 : -1.0e300,
-                                             1.0e300, g, "%.6lg"), 1, 4);
+                                             1.0e300, g, 'g', 6), 1, 4);
   grid2->addWidget(logY = new QCheckBox("log", g), 1, 6);
   logY->setChecked(fd.logy);
   grid->addWidget(g = new QGroupBox(0, Qt::Vertical, i18n("Colors"), frame),
@@ -114,8 +113,8 @@ FrameDlg::FrameDlg(QWidget* _parent, KplDoc* model, int it) :
   grid2->addWidget(exTic = new KplDoubleEdit(fd.xtic, g), 0, 1);
   grid2->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding), 0, 2);
   grid2->addWidget(new QLabel("xoff", g), 0, 3);
-  grid2->addWidget(exOff = new KplDoubleEdit(fd.xOff, 0.0, 1.0e300, g,
-                                             "%.6lg"), 0, 4);
+  grid2->addWidget(exOff = new KplDoubleEdit(fd.xOff, 0.0, 1.0e300, g, 'g', 6),
+                   0, 4);
   grid2->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding), 0, 5);
   grid2->addWidget(new QLabel("mticx", g), 0, 6);
   grid2->addWidget(emTicx = new KplSpinBox(0, 10, 1, g), 0, 7);
@@ -128,8 +127,8 @@ FrameDlg::FrameDlg(QWidget* _parent, KplDoc* model, int it) :
   grid2->addWidget(new QLabel("ytic", g), 1, 0);
   grid2->addWidget(eyTic = new KplDoubleEdit(fd.ytic, g), 1, 1);
   grid2->addWidget(new QLabel("yoff", g), 1, 3);
-  grid2->addWidget(eyOff = new KplDoubleEdit(fd.yOff, 0.0, 1.0e300, g,
-                                             "%.6lg"), 1, 4);
+  grid2->addWidget(eyOff = new KplDoubleEdit(fd.yOff, 0.0, 1.0e300, g, 'g', 6),
+                   1, 4);
   grid2->addWidget(new QLabel("mticy", g), 1, 6);
   grid2->addWidget(emTicy = new KplSpinBox(0, 10, 1, g), 1, 7);
   emTicy->setValue(fd.mticy);
@@ -203,11 +202,7 @@ FrameDlg::FrameDlg(QWidget* _parent, KplDoc* model, int it) :
   hbox->addWidget(eRelSiz = new KplSpinBox(10, 800, 1, frame));
   eRelSiz->setValue(qRound(100 * fd.relsiz));
   eRelSiz->setSuffix(" %");
-#if KDE_VERSION == 303
-  connect(this, SIGNAL(helpClicked()), SLOT(slotHelp2()));
-#else
   setHelp("SEC-FRAME");
-#endif
   connect(logX, SIGNAL(toggled(bool)), SLOT(slotLogToggled(bool)));
   connect(logY, SIGNAL(toggled(bool)), SLOT(slotLogToggled(bool)));
   connect(autoNorm, SIGNAL(toggled(bool)), SLOT(slotNormToggled(bool)));
@@ -343,17 +338,17 @@ void FrameDlg::slotAutoScale()
     ex->setValue(iex);
     emTicx->setValue(mticx);
     enDigx->setValue(ndigx);
-    exMin->setText(QString::number(xmi));
-    exMax->setText(QString::number(xma));
-    exTic->setText(QString::number(xtic));
+    exMin->setValue(xmi);
+    exMax->setValue(xma);
+    exTic->setValue(xtic);
     ey->setValue(iey);
     emTicy->setValue(mticy);
     enDigy->setValue(ndigy);
-    eyMin->setText(QString::number(ymi));
-    eyMax->setText(QString::number(yma));
-    eyTic->setText(QString::number(ytic));
-    exOff->setText("0");
-    eyOff->setText("0");
+    eyMin->setValue(ymi);
+    eyMax->setValue(yma);
+    eyTic->setValue(ytic);
+    exOff->setValue(0.0);
+    eyOff->setValue(0.0);
   }
 }
 
@@ -366,11 +361,3 @@ void FrameDlg::slotApply()
 {
   getValues(false);
 }
-
-void FrameDlg::slotHelp2()
-{
-#if KDE_VERSION == 303
-  kapp->startServiceByDesktopName("konqueror", QString("help:/kpl/frame.html"),
-                                  0, 0, 0, "", true);
-#endif
-}
