@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -91,8 +91,6 @@ protected slots:
   virtual void slotOk();
   /** Applies settings without leaving the dialog. */
   virtual void slotApply();
-  /** Displays help for the frame settings dialog. */
-  void slotHelp2();
 };
 
 #endif
