@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Aug 29 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -116,7 +116,8 @@ protected:
   friend class KplApp;
   friend class FitDlg;
   friend class SplFitDlg;
-  friend KplDoc;
+  friend class KplDoc;
+  friend class KplView;
 };
 
 #endif
