@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -20,34 +20,36 @@
  ***************************************************************************/
 
 #include <math.h>
-#include <dlfcn.h>
-#include <qfileinfo.h>
-#include <qlistbox.h>
-#include <qgroupbox.h>
-#include <qlineedit.h>
-#include <qmultilinedit.h>
 #include <qdir.h>
+#include <qfileinfo.h>
+#include <qgroupbox.h>
 #include <qlabel.h>
 #include <qlayout.h>
+#include <qlistbox.h>
+#include <qlineedit.h>
 #include <klocale.h>
+#include <qmultilinedit.h>
 #include <kapp.h>
-#include <kurl.h>
-#include <kfiledialog.h>
 #include <kcolorbtn.h>
-#include <kmessagebox.h>
+#include <kfiledialog.h>
 #include <kio/netaccess.h>
+#include <kmessagebox.h>
+#include <kurl.h>
+#include "fitpack.h"
 #include "funcdlg.h"
-#include "kpldoc.h"
-#include "symboldlg.h"
-#include "utils.h"
 #include "funitem.h"
+#include "kpldoc.h"
 #include "kpldoubleedit.h"
 #include "kplspinbox.h"
+#include "rootdlg.h"
+#include "splineitem.h"
+#include "symboldlg.h"
+#include "utils.h"
 
 FuncDlg::FuncDlg(QWidget* _parent, KplDoc* model, FunItem* fd0) :
  KDialogBase(Plain, i18n("Function"),
-             Help | Ok | Apply | Cancel | User1, Ok, _parent, 0,
-             true, false, i18n("&Export")),
+             Help | Ok | Apply | Cancel | User1 | User2, Ok, _parent, 0,
+             true, false, i18n("&Export"), i18n("R&oots")),
  m(model), fd(fd0)
 {
   fdt = new FunItem(*fd);
@@ -83,13 +85,18 @@ FuncDlg::FuncDlg(QWidget* _parent, KplDoc* model, FunItem* fd0) :
   vbox->addWidget(g = new QGroupBox(0, Qt::Vertical, i18n("Range"), frame));
   grid = new QGridLayout(g->layout(), 3, 5, spacingHint());
   grid->addWidget(new QLabel("xmin", g), 0, 0);
-  grid->addWidget(exMin = new KplDoubleEdit(fd->tmin, g), 0, 1);
+  char frm = m->options()->format;
+  int prec = m->options()->prec;
+  grid->addWidget(exMin = new KplDoubleEdit(fd->tmin, g, frm, prec), 0, 1);
+  int w = exMin->fontMetrics().width(m->number(-1.0e-123 / 3.0)) + 3;
+  exMin->setMinimumWidth(w);
   grid->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding), 0, 2);
   grid->addWidget(new QLabel("xmax", g), 0, 3);
-  grid->addWidget(exMax = new KplDoubleEdit(fd->tmax, g), 0, 4);
+  grid->addWidget(exMax = new KplDoubleEdit(fd->tmax, g, frm, prec), 0, 4);
+  exMax->setMinimumWidth(w);
   grid->addLayout(hbox = new QHBoxLayout(1), 1, 0);
   QLabel* l = new QLabel("D", g);
-#if (KDE_VERSION_MAJOR > 2) || (KDE_VERSION_MINOR > 8)
+#if KDE_VERSION_MAJOR > 2
   l->setFont(QFont("Symbol", 12, QFont::Normal, false));
 #else
   l->setFont(QFont("Symbol", 12, QFont::Normal, false, QFont::AnyCharSet));
@@ -97,12 +104,14 @@ FuncDlg::FuncDlg(QWidget* _parent, KplDoc* model, FunItem* fd0) :
   hbox->addWidget(l);
   hbox->addWidget(new QLabel("x", g));
   hbox->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding));
-  grid->addWidget(exStep = new KplDoubleEdit(fd->dt, g), 1, 1);
+  grid->addWidget(exStep = new KplDoubleEdit(fd->dt, g, frm, prec), 1, 1);
+  exStep->setMinimumWidth(w);
   grid->addWidget(new QLabel(i18n("x normalization"), g), 2, 0);
   grid->addWidget(efx = new KplDoubleEdit(fd->fx, g), 2, 1);
   grid->addWidget(new QLabel(i18n("y normalization"), g), 2, 3);
   grid->addWidget(efy = new KplDoubleEdit(fd->fy, g), 2, 4);
-  vbox->addWidget(g = new QGroupBox(0, Qt::Vertical, i18n("Representation"), frame));
+  vbox->addWidget(g = new QGroupBox(0, Qt::Vertical, i18n("Representation"),
+                                    frame));
   grid = new QGridLayout(g->layout(), 2, 6, spacingHint());
   grid->addWidget(new QLabel(i18n("Symbol"), g), 0, 0);
   grid->addWidget(symb = new KplSpinBox(-17, 9, 1, g), 0, 1);
@@ -117,11 +126,7 @@ FuncDlg::FuncDlg(QWidget* _parent, KplDoc* model, FunItem* fd0) :
   grid->addWidget(new QLabel(i18n("Color"), g), 1, 4);
   grid->addWidget(colData = new KColorButton(fd->color, g), 1, 5);
   colData->setMinimumWidth(50);
-#if KDE_VERSION == 303
-  connect(this, SIGNAL(helpClicked()), SLOT(slotHelp2()));
-#else
   setHelp("SEC-FUNC");
-#endif
   Utils::setSize(this, "FuncDialog");
 }
 
@@ -131,13 +136,13 @@ FuncDlg::~FuncDlg()
   delete fdt;
 }
 
-void FuncDlg::getFunc(QWidget* parent, QLineEdit* name, QLineEdit* func)
+void FuncDlg::getFunc(QWidget* parent, QLineEdit* name, QLineEdit* func, bool d3)
 {
   QFileInfo fi(name->text());
   QString path = fi.dirPath(true) + "/" + fi.baseName() + ".def";
   QFile f(path);
   if (f.open(IO_ReadOnly)) {
-    ChooseFuncDlg dlg(parent, &f, func);
+    ChooseFuncDlg dlg(parent, &f, func, d3);
     dlg.exec();
   } else
     KMessageBox::error(parent,
@@ -154,7 +159,7 @@ bool FuncDlg::getTemp()
   fdt->pathy = fileName->text();
   fdt->namey = func->text();
   if (fdt->hmody)
-    dlclose(fdt->hmody);
+    lt_dlclose(fdt->hmody);
   if (FunItem::getFuncAddr(fdt->pathy.path(), fdt->namey, &fdt->hmody,
                            &fdt->fkty))
     return false;
@@ -223,6 +228,32 @@ void FuncDlg::slotUser1()
   }
 }
 
+void FuncDlg::slotUser2()
+{
+  if (getTemp())
+    if (fdt->tmax > fdt->tmin) {
+      int n = fdt->calcTable(fdt->logxo);
+      QArray<double> w(n);
+      for (int i = 0; i < n; i++)
+        w[i] = 1.0;
+      int nest = n + 4;
+      int lwrk = n * 4 + nest * 16;
+      QArray<double> wrk(lwrk);
+      QArray<int> iwrk(nest);
+      double fp;
+      SplineItem spl;
+      spl.t.resize(nest);
+      spl.c.resize(nest);
+      int ier;
+      FitPack::curfit(0, n, fdt->tv, fdt->yv, w, fdt->tmin, fdt->tmax, 3, 0.0,
+                      nest, &spl.nk, spl.t.data(), spl.c.data(), &fp,
+                      wrk.data(), lwrk, iwrk.data(), &ier);
+      RootDlg dlg(this, m, &spl);
+      dlg.exec();
+    } else
+      KMessageBox::sorry(this, i18n("invalid range!"));
+}
+
 void FuncDlg::slotOk()
 {
   getValues(true);
@@ -233,14 +264,6 @@ void FuncDlg::slotApply()
   getValues(false);
 }
 
-void FuncDlg::slotHelp2()
-{
-#if KDE_VERSION == 303
-  kapp->startServiceByDesktopName("konqueror", QString("help:/kpl/func.html"),
-                                  0, 0, 0, "", true);
-#endif
-}
-
 ParFuncDlg::ParFuncDlg(QWidget* _parent, KplDoc* model, ParFunItem* fd0) :
  KDialogBase(Plain, i18n("Parametric function"),
              Help | Ok | Apply | Cancel | User1, Ok, _parent, 0,
@@ -304,13 +327,18 @@ ParFuncDlg::ParFuncDlg(QWidget* _parent, KplDoc* model, ParFunItem* fd0) :
   vbox->addWidget(g = new QGroupBox(0, Qt::Vertical, i18n("Range"), frame));
   grid = new QGridLayout(g->layout(), 3, 5, spacingHint());
   grid->addWidget(new QLabel("tmin", g), 0, 0);
-  grid->addWidget(etMin = new KplDoubleEdit(fd->tmin, g), 0, 1);
+  char frm = m->options()->format;
+  int prec = m->options()->prec;
+  grid->addWidget(etMin = new KplDoubleEdit(fd->tmin, g, frm, prec), 0, 1);
+  int w = etMin->fontMetrics().width(m->number(-1.0e-123 / 3.0)) + 3;
+  etMin->setMinimumWidth(w);
   grid->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding), 0, 2);
   grid->addWidget(new QLabel("tmax", g), 0, 3);
-  grid->addWidget(etMax = new KplDoubleEdit(fd->tmax, g), 0, 4);
+  grid->addWidget(etMax = new KplDoubleEdit(fd->tmax, g, frm, prec), 0, 4);
+  etMax->setMinimumWidth(w);
   grid->addLayout(hbox = new QHBoxLayout(1), 1, 0);
   QLabel* l = new QLabel("D", g);
-#if (KDE_VERSION_MAJOR > 2) || (KDE_VERSION_MINOR > 8)
+#if KDE_VERSION_MAJOR > 2
   l->setFont(QFont("Symbol", 12, QFont::Normal, false));
 #else
   l->setFont(QFont("Symbol", 12, QFont::Normal, false, QFont::AnyCharSet));
@@ -318,7 +346,8 @@ ParFuncDlg::ParFuncDlg(QWidget* _parent, KplDoc* model, ParFunItem* fd0) :
   hbox->addWidget(l);
   hbox->addWidget(new QLabel("t", g));
   hbox->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding));
-  grid->addWidget(etStep = new KplDoubleEdit(fd->dt, g), 1, 1);
+  grid->addWidget(etStep = new KplDoubleEdit(fd->dt, g, frm, prec), 1, 1);
+  etStep->setMinimumWidth(w);
   grid->addWidget(new QLabel(i18n("x normalization"), g), 2, 0);
   grid->addWidget(efx = new KplDoubleEdit(fd->fx, g), 2, 1);
   grid->addWidget(new QLabel(i18n("y normalization"), g), 2, 3);
@@ -339,11 +368,7 @@ ParFuncDlg::ParFuncDlg(QWidget* _parent, KplDoc* model, ParFunItem* fd0) :
   grid->addWidget(new QLabel(i18n("Color"), g), 1, 4);
   grid->addWidget(colData = new KColorButton(fd->color, g), 1, 5);
   colData->setMinimumWidth(50);
-#if KDE_VERSION == 303
-  connect(this, SIGNAL(helpClicked()), SLOT(slotHelp2()));
-#else
   setHelp("SEC-PARFUNC");
-#endif
   Utils::setSize(this, "ParFuncDialog");
 }
 
@@ -363,14 +388,14 @@ bool ParFuncDlg::getTemp()
   fdt->pathx = fileNamex->text();
   fdt->namex = funcx->text();
   if (fdt->hmodx)
-    dlclose(fdt->hmodx);
+    lt_dlclose(fdt->hmodx);
   if (FunItem::getFuncAddr(fdt->pathx.path(), fdt->namex, &fdt->hmodx,
                            &fdt->fktx))
     return false;
   fdt->pathy = fileNamey->text();
   fdt->namey = funcy->text();
   if (fdt->hmody)
-    dlclose(fdt->hmody);
+    lt_dlclose(fdt->hmody);
   if (FunItem::getFuncAddr(fdt->pathy.path(), fdt->namey, &fdt->hmody,
                            &fdt->fkty))
     return false;
@@ -475,12 +500,3 @@ void ParFuncDlg::slotApply()
 {
   getValues(false);
 }
-
-void ParFuncDlg::slotHelp2()
-{
-#if KDE_VERSION == 303
-  kapp->startServiceByDesktopName("konqueror",
-                                  QString("help:/kpl/parfunc.html"),
-                                  0, 0, 0, "", true);
-#endif
-}
