@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Aug 29 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -22,7 +22,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
-#include <dlfcn.h>
 #include <qfileinfo.h>
 #include <qtextstream.h>
 #include <qurl.h>
@@ -47,6 +46,7 @@ FunItem::FunItem(const FunItem& f) :
  tmino(f.tmino), tmaxo(f.tmaxo), dto(f.dto), fkty(f.fkty), fktyo(f.fktyo),
  tv(f.tv), yv(f.yv), namey(f.namey), pathy(f.pathy), hmody(f.hmody)
 {
+  lt_dlinit();
   memcpy(py, f.py, sizeof(py));
   memcpy(pyo, f.pyo, sizeof(pyo));
   tv.detach();
@@ -66,6 +66,7 @@ FunItem::FunItem(KSimpleConfig* plo, Kpl::AutoStruct* aut, const KURL& uPlo) :
  ScaledItem(plo, aut), logxo(false), tmino(0.0), tmaxo(0.0), dto(0.0),
  fktyo(0)
 {
+  lt_dlinit();
   tmin = plo->readDoubleNumEntry("xfmin");
   tmax = plo->readDoubleNumEntry("xfmax", tmin + 1.0);
   dt = plo->readDoubleNumEntry("dx");
@@ -94,7 +95,8 @@ FunItem::FunItem(bool act, int sym, const QString& col,
 FunItem::~FunItem()
 {
   if (hmody)
-    dlclose(hmody);
+    lt_dlclose(hmody);
+  lt_dlexit();
 }
 
 FunItem& FunItem::operator=(const FunItem& f)
@@ -119,7 +121,7 @@ FunItem& FunItem::operator=(const FunItem& f)
     namey = f.namey;
     pathy = f.pathy;
     if (hmody)
-      dlclose(hmody);
+      lt_dlclose(hmody);
     hmody = 0;
     if (f.hmody)
       getFuncAddr(pathy.path(), namey, &hmody, &fkty);
@@ -149,9 +151,11 @@ void FunItem::writePlo(KSimpleConfig* plo, const KURL& url, bool _abs,
 {
   plo->writeEntry("Type", "FUNITEM");
   ScaledItem::writePlo(plo, url, _abs, m);
-  plo->writeEntry("xfmin", tmin);
-  plo->writeEntry("xfmax", tmax);
-  plo->writeEntry("dx", dt);
+  char frm = m->options()->format;
+  int prec = m->options()->prec;
+  plo->writeEntry("xfmin", tmin, true, false, frm, prec);
+  plo->writeEntry("xfmax", tmax, true, false, frm, prec);
+  plo->writeEntry("dx", dt, true, false, frm, prec);
   QStrList list;
   for (int i = 0; i < KPL_NPMAX; i++)
     list.insert(i, m->number(py[i]));
@@ -213,34 +217,31 @@ void FunItem::exportTable(QTextStream& ts, KplDoc* m) const
        << m->number(fy * yv[i]) << "\n";
 }
 
-bool FunItem::getFuncAddr(const QString& path, const QString& name, void** hmod,
+bool FunItem::getFuncAddr(const QString& path, const QString& name,
+                          lt_dlhandle* hmod,
                           double (**fkt)(double, const double*))
 {
   *hmod = 0;
   *fkt = 0;
-  if (path.isEmpty() || name.isEmpty()) {
+  if (path.isEmpty() || name.isEmpty())
     KMessageBox::sorry(0, i18n("no library or no function specified!"));
-    return true;
-  }
-  if (!(*hmod = dlopen(path, RTLD_NOW))) {
-    KMessageBox::error(0, i18n("while trying to open") + "\n" + path +
-                       "\n" + dlerror());
-    return true;
-  } else {
-    *fkt = (double (*)(double, const double *)) dlsym(*hmod, name);
-    if (const char* error = dlerror()) {
-      KMessageBox::error(0, i18n("while trying to determine the address of") +
-                         "\n" + name + "\n" + error);
-      dlclose(*hmod);
-      *hmod = 0;
-      return true;
-    } else
-      return false;
-  }
+  else
+    if (!(*hmod = lt_dlopen(path)))
+      KMessageBox::error(0, lt_dlerror());
+    else
+      if ((*fkt = (double (*)(double, const double *)) lt_dlsym(*hmod, name)))
+        return false;
+      else {
+        KMessageBox::error(0, lt_dlerror());
+        lt_dlclose(*hmod);
+        *hmod = 0;
+      }
+  return true;
 }
 
 void FunItem::init()
 {
+  lt_dlinit();
   memset(py, 0, sizeof(py));
   memset(pyo, 0, sizeof(pyo));
 }
@@ -357,7 +358,7 @@ ParFunItem::ParFunItem(bool act, int sym, const QString& col,
 ParFunItem::~ParFunItem()
 {
   if (hmodx)
-    dlclose(hmodx);
+    lt_dlclose(hmodx);
 }
 
 ParFunItem& ParFunItem::operator=(const ParFunItem& f)
@@ -373,7 +374,7 @@ ParFunItem& ParFunItem::operator=(const ParFunItem& f)
     namex = f.namex;
     pathx = f.pathx;
     if (hmodx)
-      dlclose(hmodx);
+      lt_dlclose(hmodx);
     hmodx = 0;
     if (f.hmodx)
       getFuncAddr(pathx.path(), namex, &hmodx, &fktx);
@@ -403,9 +404,11 @@ void ParFunItem::writePlo(KSimpleConfig* plo, const KURL& url, bool _abs,
 {
   plo->writeEntry("Type", "PARFUNITEM");
   ScaledItem::writePlo(plo, url, _abs, m);
-  plo->writeEntry("tmin", tmin);
-  plo->writeEntry("tmax", tmax);
-  plo->writeEntry("dt", dt);
+  char frm = m->options()->format;
+  int prec = m->options()->prec;
+  plo->writeEntry("tmin", tmin, true, false, frm, prec);
+  plo->writeEntry("tmax", tmax, true, false, frm, prec);
+  plo->writeEntry("dt", dt, true, false, frm, prec);
   QStrList lx, ly;
   for (int i = 0; i < KPL_NPMAX; i++) {
     lx.insert(i, m->number(px[i]));
