@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Aug 29 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -23,6 +23,7 @@
 #define FUNITEM_H
 
 #include <kurl.h>
+#include "ltdl.h"
 #include "kplitem.h"
 
 class QTextStream;
@@ -94,7 +95,8 @@ public:
    * @param fkt pointer to function address.
    */
   static bool getFuncAddr(const QString& path, const QString& name,
-                          void** hmod, double (**fkt)(double, const double*));
+                          lt_dlhandle* hmod,
+                          double (**fkt)(double, const double*));
 
 protected:
   /**
@@ -117,13 +119,14 @@ protected:
   mutable QArray<double> tv, yv;
   QString namey;
   KURL pathy;
-  void* hmody;
+  lt_dlhandle hmody;
 
   friend class FitDlg;
-  friend class LMFit;
   friend class FuncDlg;
-  friend class KplDoc;
+  friend class LMFit;
   friend class KplApp;
+  friend class KplDoc;
+  friend class KplView;
 };
 
 /**
@@ -203,7 +206,7 @@ protected:
   mutable QArray<double> xv;
   QString namex;
   KURL pathx;
-  void* hmodx;
+  lt_dlhandle hmodx;
   friend class ParFuncDlg;
   friend class KplApp;
 };
