@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -19,26 +19,27 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <dlfcn.h>
-#include <qfileinfo.h>
-#include <qpushbutton.h>
 #include <qbuttongroup.h>
-#include <klistview.h>
-#include <qpopupmenu.h>
+#include <qcheckbox.h>
+#include <qfileinfo.h>
 #include <qheader.h>
-#include <qtooltip.h>
 #include <qlayout.h>
-#include <klocale.h>
+#include <qpopupmenu.h>
+#include <qpushbutton.h>
+#include <qtimer.h>
+#include <qtooltip.h>
 #include <kapp.h>
-#include <kiconloader.h>
 #include <kglobal.h>
-#include "itemdlg.h"
-#include "kpldoc.h"
-#include "kplchecklistitem.h"
-#include "fitdlg.h"
-#include "splfitdlg.h"
+#include <kiconloader.h>
+#include <klistview.h>
+#include <klocale.h>
 #include "arrayitem.h"
+#include "fitdlg.h"
 #include "funitem.h"
+#include "itemdlg.h"
+#include "kplchecklistitem.h"
+#include "kpldoc.h"
+#include "splfitdlg.h"
 #include "splineitem.h"
 #include "utils.h"
 
@@ -113,13 +114,7 @@ void NewItemDlg::slotClicked(int id)
 
 void NewItemDlg::slotHelp()
 {
-#if KDE_VERSION == 303
-  kapp->startServiceByDesktopName("konqueror",
-                                  QString("help:/kpl/newitem.html"),
-                                  0, 0, 0, "", true);
-#else
   kapp->invokeHelp("SEC-NEWITEM");
-#endif
 }
 
 ItemDlg::ItemDlg(KplDoc* model) : m(model)
@@ -140,24 +135,24 @@ ItemDlg::ItemDlg(KplDoc* model) : m(model)
   itemList->setRootIsDecorated(true);
   itemList->setSorting(-1);
   itemList->header()->setClickEnabled(false);
-#if (KDE_VERSION_MAJOR > 2) || (KDE_VERSION_MINOR > 8)
+  itemList->setDragEnabled(true);
+  itemList->setAcceptDrops(true);
+#if KDE_VERSION_MAJOR > 2
   itemList->setSelectionModeExt(KListView::FileManager);
+  connect(itemList, SIGNAL(contextMenuRequested(QListViewItem*,
+    const QPoint&, int)), SLOT(slotPopup(QListViewItem*, const QPoint&)));
 #else
   itemList->setSelectionModeExt(KListView::Konqueror);
+  connect(itemList, SIGNAL(rightButtonClicked(QListViewItem*,
+    const QPoint&, int)), SLOT(slotPopup(QListViewItem*, const QPoint&)));
 #endif
-/*  itemList->setDragEnabled(true);
-  itemList->setAcceptDrops(true); */
+  connect(itemList,
+          SIGNAL(moved(QListViewItem*, QListViewItem*, QListViewItem*)),
+          SLOT(slotMoved(QListViewItem*, QListViewItem*, QListViewItem*)));
   connect(itemList, SIGNAL(returnPressed(QListViewItem*)),
           SLOT(slotList(QListViewItem*)));
   connect(itemList, SIGNAL(currentChanged(QListViewItem*)),
           SLOT(slotSelectionChanged(QListViewItem*)));
-#if (KDE_VERSION_MAJOR > 2) || (KDE_VERSION_MINOR > 8)
-  connect(itemList, SIGNAL(contextMenuRequested(QListViewItem*,
-    const QPoint&, int)), SLOT(slotPopup(QListViewItem*, const QPoint&)));
-#else
-  connect(itemList, SIGNAL(rightButtonClicked(QListViewItem*,
-    const QPoint&, int)), SLOT(slotPopup(QListViewItem*, const QPoint&)));
-#endif
   connect(itemList, SIGNAL(executed(QListViewItem*)),
           SLOT(slotExecuted(QListViewItem*)));
   QHBoxLayout* hbox = new QHBoxLayout(this, marginHint(), spacingHint());
@@ -170,7 +165,10 @@ ItemDlg::ItemDlg(KplDoc* model) : m(model)
   down->setPixmap(BarIcon("down"));
   connect(down, SIGNAL(clicked()), SLOT(slotMoveDown()));
   vbox->addItem(new QSpacerItem(10, 10));
-  hbox->addWidget(itemList);
+  vbox = new QVBoxLayout(hbox, spacingHint());
+  vbox->addWidget(itemList);
+  vbox->addWidget(appendItems = new QCheckBox(i18n("Append items"), this));
+  appendItems->setChecked(m->options()->appendItems);
   vbox = new QVBoxLayout(hbox, spacingHint());
   QPushButton* b = new QPushButton(i18n("&New"), this);
   vbox->addWidget(b);
@@ -236,7 +234,7 @@ void ItemDlg::updItemList()
     itemList->setSelected(itm, true);
     itemList->setCurrentItem(itm);
     itemList->ensureItemVisible(itm);
-#if (KDE_VERSION_MAJOR > 2) || (KDE_VERSION_MINOR > 8)
+#if KDE_VERSION_MAJOR > 2
     slotSelectionChanged(itm);
 #endif
   }
@@ -247,17 +245,22 @@ void ItemDlg::updItemList()
   itemList->setFocus();
 }
 
-void ItemDlg::moveItem(int di)
+void ItemDlg::moveItem()
 {
-  int is = lItem.findRef((KplCheckListItem*) itemList->currentItem());
-  int id = is + di;
-  m->moveItem(is, id);
+  m->moveItem(iSource, iDest);
   itemList->clearSelection();
-  QListViewItem* item = lItem.at(id);
+  QListViewItem* item = lItem.at(iDest);
   itemList->setCurrentItem(item);
   itemList->setSelected(item, true);
-  if (!id)
-   slotSelectionChanged(item);
+  if (!iDest)
+    slotSelectionChanged(item);
+}
+
+void ItemDlg::moveItem(int di)
+{
+  iSource = lItem.findRef((KplCheckListItem*) itemList->currentItem());
+  iDest = iSource + di;
+  moveItem();
 }
 
 void ItemDlg::keyPressEvent(QKeyEvent* e)
@@ -275,13 +278,26 @@ void ItemDlg::slotList(QListViewItem* it)
   m->items()->at(i)->editItem(this, m, i);
 }
 
+void ItemDlg::slotMoved(QListViewItem* item, QListViewItem*,
+                        QListViewItem* afterNow)
+{
+  iSource = lItem.findRef((KplCheckListItem*) item);
+  iDest = lItem.findRef((KplCheckListItem*) afterNow);
+  if (iSource >= 0) {
+    if (iDest <= iSource)
+      iDest++;
+    QTimer::singleShot(0, this, SLOT(moveItem()));
+  }
+}
+
 void ItemDlg::slotNew()
 {
   int ityp;
   NewItemDlg dlg(this, &ityp);
   if (dlg.exec()) {
-    m->newItem((KplItem::ItemTypes) ityp);
-    int it = m->items()->count() - 1;
+    int it = appendItems->isChecked() ? m->items()->count() :
+             lItem.findRef((KplCheckListItem*) itemList->currentItem());
+    m->newItem((KplItem::ItemTypes) ityp, it);
     if ((ityp == KplItem::Array) || (ityp == KplItem::Function) ||
         (ityp == KplItem::ParFunction) || (ityp == KplItem::Spline))
       for (int i = it - 1; i >= 0; i--) {
@@ -295,7 +311,7 @@ void ItemDlg::slotNew()
           break;
         }
       }
-    if (!m->items()->last()->editItem(this, m, it)) {
+    if (!m->items()->at(it)->editItem(this, m, it)) {
       m->setModified();
       m->backupItems();
     }
@@ -379,11 +395,18 @@ void ItemDlg::slotDelete()
 void ItemDlg::slotCopy()
 {
   bool b = false;
-  for (unsigned i = 0; i < m->items()->count(); i++)
-    if (itemList->isSelected(lItem.at(i))) {
-      m->items()->append(m->items()->at(i)->copy());
-      b = true;
-    }
+  if (appendItems->isChecked()) {
+    for (unsigned i = 0; i < m->items()->count(); i++)
+      if (itemList->isSelected(lItem.at(i))) {
+        m->items()->append(m->items()->at(i)->copy());
+        b = true;
+      }
+  } else
+    for (int i = m->items()->count() - 1; i >= 0; i--)
+      if (itemList->isSelected(lItem.at(i))) {
+        m->items()->insert(i, m->items()->at(i)->copy());
+        b = true;
+      }
   if (b) {
     m->setModified();
     m->backupItems();
@@ -392,13 +415,7 @@ void ItemDlg::slotCopy()
 
 void ItemDlg::slotHelp()
 {
-#if KDE_VERSION == 303
-  kapp->startServiceByDesktopName("konqueror",
-                                  QString("help:/kpl/dialogs.html#items"),
-                                  0, 0, 0, "", true);
-#else
   kapp->invokeHelp("SEC-ITEMS");
-#endif
 }
 
 void ItemDlg::slotPopup(QListViewItem* item, const QPoint& p)
