@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -150,15 +150,13 @@ void KGraph::plInit(const QPaintDevice* pd, int offLeft, int offTop)
   eraseRect(window());
   if (pd->devType() == QInternal::Printer) {
     devType = Printer;
-    pFactor = 10;
+    pFactor = 4;
     QRect r = window();
     r.setSize(pFactor * r.size());
     setWindow(r);
-    fDpi = 1.0;
-  } else {
+  } else 
     pFactor = 1;
-    fDpi = 75.0 / pdm.logicalDpiY();
-  }
+  fDpi = 75.0 / pdm.logicalDpiY();
   scalx = pFactor * pdm.logicalDpiX() / 2.54;
   scaly = -pFactor * pdm.logicalDpiY() / 2.54;
   minx0 = minx = -pFactor * offLeft;
@@ -641,7 +639,7 @@ void KGraph::text(const QString& str, int ix, int iy, int iorg, QRect* bRect)
                           QMAX(qRound(((ilev = (int) (f - levcode)) ?
                                        0.0251 : 0.0355) *
                                        relSize * fDpi * (maxx - minx)), 1),
-#if (KDE_VERSION_MAJOR > 2) || (KDE_VERSION_MINOR > 8)
+#if KDE_VERSION_MAJOR > 2
                           weight[ifnt], italic[ifnt]));
 #else
                           weight[ifnt], italic[ifnt],
