@@ -7,7 +7,7 @@
 
     begin                : Sat Apr 24 15:14:00 MEST 1999
 
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -21,66 +21,59 @@
  ***************************************************************************/
 
 #include <math.h>
-#include <qscrollbar.h>
-#include <qimage.h>
-#include <qdir.h>
-#include <qtimer.h>
 #include <qcursor.h>
-#include <klocale.h>
-#include <kiconloader.h>
-#include <kfiledialog.h>
-#include <kprocess.h>
-#include <kkeydialog.h>
-#include <kmenubar.h>
-#include <kstatusbar.h>
+#include <qcheckbox.h>
+#include <qdir.h>
+#include <qimage.h>
+#include <qscrollbar.h>
+#include <qtimer.h>
 #include <kaccel.h>
-#include <kconfig.h>
-#include <kapp.h>
-#include <kmessagebox.h>
-#include <kstddirs.h>
 #include <kaction.h>
-#include <kstdaction.h>
+#include <kapp.h>
+#include <kconfig.h>
 #include <kedittoolbar.h>
-
-#if KDE_VERSION == 303
-#include <khelpmenu.h>
-#include <kaboutdata.h>
-#endif
-
+#include <kfiledialog.h>
+#include <kiconloader.h>
+#include <kkeydialog.h>
+#include <klocale.h>
+#include <kmenubar.h>
+#include <kmessagebox.h>
+#include <kprocess.h>
+#include <kstatusbar.h>
+#include <kstdaction.h>
+#include <kstddirs.h>
 #if (KDE_VERSION_MAJOR > 2) || (KDE_VERSION_MINOR > 1)
 #include <kprinter.h>
 #else
 #include <qprinter.h>
 #endif
+#include "arcitem.h"
+#include "arrayitem.h"
+#include "autodlg.h"
+#include "autofitdlg.h"
+#include "basicdlg.h"
+#include "ellipseitem.h"
+#include "fitdlg.h"
+#include "frameitem.h"
+#include "funitem.h"
+#include "itemdlg.h"
 #include "kpl.h"
 #include "kpldoc.h"
 #include "kplview.h"
-#include "zoomdlg.h"
-#include "refreshdlg.h"
-#include "basicdlg.h"
-#include "autodlg.h"
-#include "itemdlg.h"
-#include "autofitdlg.h"
-#include "fitdlg.h"
-#include "splfitdlg.h"
-#include "psgraph.h"
-#include "frameitem.h"
-#include "arrayitem.h"
-#include "funitem.h"
 #include "legenditem.h"
 #include "lineitem.h"
-#include "arcitem.h"
-#include "textitem.h"
-#include "ellipseitem.h"
+#include "psgraph.h"
+#include "refreshdlg.h"
+#include "splfitdlg.h"
 #include "splineitem.h"
+#include "textitem.h"
 #include "threeditem.h"
 #include "utils.h"
+#include "zoomdlg.h"
 
-KplApp::KplApp(QWidget*, const char* _name) :
- KMainWindow(0, _name), DCOPObject("KplIface"), plot(false), tRefresh(5)
+KplApp::KplApp() : KMainWindow(0, "Kpl"), DCOPObject("KplIface"), itemDlg(0),
+  config(kapp->config()), plot(false), tRefresh(5)
 {
-  config = kapp->config();
-  itemDlg = 0;
   setMinimumSize(120, 80);
   initDocument();
   initActions();
@@ -104,7 +97,9 @@ KplApp::KplApp(QWidget*, const char* _name) :
 
 KplApp::~KplApp()
 {
+#if KDE_VERSION_MAJOR < 3
   delete key_accel;
+#endif
   delete itemDlg;
 }
 
@@ -152,7 +147,7 @@ void KplApp::initActions()
                                    actionCollection());
   a->setStatusText(i18n("Creates a new plot"));
   a = new KAction(i18n("&Open Plot File..."),
-#if (KDE_VERSION_MAJOR > 2) || (KDE_VERSION_MINOR > 8)
+#if KDE_VERSION_MAJOR > 2
                   "fileopen",
 #else
                   QIconSet(BarIcon("fileopen")),
@@ -161,7 +156,7 @@ void KplApp::initActions()
                   actionCollection(), "open_plot");
   a->setStatusText(i18n("Opens an existing plot file"));
   a = new KAction(i18n("Open &Data File..."),
-#if (KDE_VERSION_MAJOR > 2) || (KDE_VERSION_MINOR > 8)
+#if KDE_VERSION_MAJOR > 2
                   "fileopen",
 #else
                   QIconSet(BarIcon("fileopen")),
@@ -276,32 +271,6 @@ void KplApp::initActions()
   a = KStdAction::saveOptions(this, SLOT(slotOptionsSave()),
                               actionCollection());
   a->setStatusText(i18n("Saves settings"));
-
-#if KDE_VERSION == 303
-  KAboutData* aboutData = new KAboutData("kpl", I18N_NOOP("Kpl"), VERSION,
-                       "An application for plotting of data sets and functions",
-                       KAboutData::License_GPL, "(c) 2002, Werner Stille",
-                       0, 0, "stille@uni-freiburg.de");
-  aboutData->addAuthor("Werner Stille", 0, "stille@uni-freiburg.de");
-  KHelpMenu* hm = new KHelpMenu(this, aboutData);
-  (KStdAction::helpContents(this, SLOT(slotHelpContents()), actionCollection(),
-                           "help_contents"))->setShortcut(Key_F1);
-  KStdAction::reportBug(hm, SLOT(reportBug()), actionCollection(),
-                        "help_report_bug");
-  KStdAction::aboutApp(hm, SLOT(aboutApplication()), actionCollection(),
-                       "help_about_app");
-  KStdAction::aboutKDE(hm, SLOT(aboutKDE()), actionCollection(),
-                       "help_about_kde");
-  setHelpMenuEnabled(false);
-#endif
-}
-
-void KplApp::slotHelpContents()
-{
-#if KDE_VERSION == 303
-  kapp->startServiceByDesktopName("konqueror", QString("help:/kpl/index.html"),
-                                  0, 0, 0, "", true);
-#endif
 }
 
 void KplApp::calcStatusBar()
@@ -351,6 +320,7 @@ void KplApp::newStatusBar()
 
 void KplApp::initKeyAccel()
 {
+#if KDE_VERSION_MAJOR < 3
   key_accel = new KAccel(this);
   (new KAction(i18n("Scroll Left"), Key_Left, view, SLOT(slotScrollLeft()),
                actionCollection(), "cursor_left"))->plugAccel(key_accel);
@@ -384,6 +354,40 @@ void KplApp::initKeyAccel()
   (new KAction(i18n("Scroll to Top Margin"), Key_End, view,
                SLOT(slotScrollEndUp()), actionCollection(),
                "margin_top"))->plugAccel(key_accel);
+#else
+  new KAction(i18n("Scroll Left"), Key_Left, view, SLOT(slotScrollLeft()),
+              actionCollection(), "cursor_left");
+  new KAction(i18n("Scroll Right"), Key_Right, view, SLOT(slotScrollRight()),
+              actionCollection(), "cursor_right");
+  new KAction(i18n("Scroll Up"), Key_Up, view, SLOT(slotScrollUp()),
+              actionCollection(), "cursor_up");
+  new KAction(i18n("Scroll Down"), Key_Down, view, SLOT(slotScrollDown()),
+              actionCollection(), "cursor_down");
+  new KAction(i18n("Scroll Page Up"), Key_PageUp, view,
+              SLOT(slotScrollPageUp()), actionCollection(),
+              "page_up");
+  new KAction(i18n("Scroll Page Down"), Key_PageDown, view,
+              SLOT(slotScrollPageDown()), actionCollection(),
+              "page_down");
+  new KAction(i18n("Scroll Page Left"), CTRL + Key_PageUp, view,
+              SLOT(slotScrollPageLeft()), actionCollection(),
+              "page_left");
+  new KAction(i18n("Scroll Page Right"), CTRL + Key_PageDown, view,
+              SLOT(slotScrollPageRight()), actionCollection(),
+              "page_right");
+  new KAction(i18n("Scroll to Left Margin"), CTRL + Key_Home, view,
+              SLOT(slotScrollHomeLeft()), actionCollection(),
+              "margin_left");
+  new KAction(i18n("Scroll to Bottom Margin"), Key_Home, view,
+              SLOT(slotScrollHomeDown()), actionCollection(),
+              "margin_bottom");
+  new KAction(i18n("Scroll to Right Margin"), CTRL + Key_End, view,
+              SLOT(slotScrollEndRight()), actionCollection(),
+              "margin_right");
+  new KAction(i18n("Scroll to Top Margin"), Key_End, view,
+              SLOT(slotScrollEndUp()), actionCollection(),
+              "margin_top");
+#endif
   createGUI();
   if (!showToolbar->isChecked())
     toolBar("mainToolBar")->hide();
@@ -413,6 +417,8 @@ void KplApp::saveOptions(bool saveAll)
     config->writeEntry("ShowStatusbar", showStatusbar->isChecked());
     config->writeEntry("ShowItemDialog", itemDlg ?
                        itemDlg->isVisible() : false);
+    if (itemDlg)
+      config->writeEntry("AppendItems", itemDlg->appendItems->isChecked());
     config->writeEntry("ToolBarPos", (int) toolBar("mainToolBar")->barPos());
     config->writeEntry("Directory", doc->currentDir());
     config->writeEntry("Width", width());
@@ -488,6 +494,7 @@ void KplApp::readOptions()
   showStatusbar->setChecked(config->readBoolEntry("ShowStatusbar", true));
   if (!showStatusbar->isChecked())
     statusBar()->hide();
+  doc->aut.appendItems = config->readBoolEntry("AppendItems", true);
   if (config->readBoolEntry("ShowItemDialog")) {
     slotEditItems();
     config->setGroup(kapp->instanceName());
@@ -861,7 +868,11 @@ void KplApp::slotFileQuit()
 {
   slotStatusMsg(i18n("Exiting..."));
   if (memberList)
+#if KDE_VERSION_MAJOR > 2
+    for (KMainWindow* w = memberList->first(); w; w = memberList->next())
+#else
     for (KMainWindow* w = memberList->first(); w; w = memberList->first())
+#endif
       if (!w->close()) {
         slotStatusMsg(i18n("Ready."));
         break;
