@@ -7,7 +7,7 @@
 
     begin                : Sat Apr 24 15:14:00 MEST 1999
 
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -32,16 +32,16 @@
 #include <kurl.h>
 
 class QStrList;
-class KURL;
 class KAccel;
 class KAction;
-class KToggleAction;
 class KRecentFilesAction;
-class KplView;
-class KplDoc;
-class ItemDlg;
+class KToggleAction;
+class KURL;
 class ArrayItem;
 class FunItem;
+class ItemDlg;
+class KplDoc;
+class KplView;
 
 /**
   * Kpl application.
@@ -54,7 +54,7 @@ class KplApp : public KMainWindow, public DCOPObject
   Q_OBJECT
 public:
   /** Constructor. Creates a kpl window. */
-  KplApp(QWidget* parent = 0, const char* name = 0);
+  KplApp();
   /** Destructor. */
   ~KplApp();
   /**
@@ -838,7 +838,7 @@ protected:
   int tRefresh, xPrec, yPrec;
   double fz;
 
-  friend KplView;
+  friend class KplView;
 
 public slots:
   /**
@@ -926,8 +926,6 @@ protected slots:
   void slotOptionsAutoFit();
   /** Saves options. */
   void slotOptionsSave();
-  /** Displays the help page. */
-  void slotHelpContents();
   /**
    * Changes the status message.
    * @param text pointer to new message text.
