@@ -70,6 +70,8 @@ public:
     virtual double chiSquare();
     virtual int saveFitPar( const QString& url );
     virtual int exportValues( const QString& url, int iItem );
+protected:
+    KplApp_stub() : DCOPStub( never_use ) {};
 };
 
 
