@@ -7,7 +7,7 @@
 
     begin                : Sat Apr 24 15:14:00 MEST 1999
 
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -141,51 +141,56 @@ void KplDoc::freeAllItems()
   setModified(false);
 }
 
-void KplDoc::newItem(KplItem::ItemTypes ityp)
+void KplDoc::newItem(KplItem::ItemTypes ityp, int index)
 {
+  KplItem* it = 0;
   switch (ityp) {
     case KplItem::Frame:
-      itd.append(new FrameItem(&aut));
+      it = new FrameItem(&aut);
       break;
     case KplItem::Array:
-      itd.append(new ArrayItem(&aut));
+      it = new ArrayItem(&aut);
       break;
     case KplItem::Function:
-      itd.append(new FunItem(&aut));
+      it = new FunItem(&aut);
       break;
     case KplItem::ParFunction:
-      itd.append(new ParFunItem(&aut));
+      it = new ParFunItem(&aut);
       break;
     case KplItem::Spline:
-      itd.append(new SplineItem(&aut));
+      it = new SplineItem(&aut);
       break;
     case KplItem::Array3D:
-      itd.append(new Array3DItem(&aut));
+      it = new Array3DItem(&aut);
       break;
     case KplItem::Function3D:
-      itd.append(new Fun3DItem(&aut));
+      it = new Fun3DItem(&aut);
       break;
     case KplItem::Legend:
-      itd.append(new LegendItem(&aut));
+      it = new LegendItem(&aut);
       break;
     case KplItem::Text:
-      itd.append(new TextItem(&aut));
+      it = new TextItem(&aut);
       break;
     case KplItem::Line:
-      itd.append(new LineItem(&aut));
+      it = new LineItem(&aut);
       break;
     case KplItem::Arrow:
-      itd.append(new ArrowItem(&aut));
+      it = new ArrowItem(&aut);
       break;
     case KplItem::Arc:
-      itd.append(new ArcItem(&aut));
+      it = new ArcItem(&aut);
       break;
     case KplItem::Rectangle:
-      itd.append(new RectItem(&aut));
+      it = new RectItem(&aut);
       break;
     case KplItem::Ellipse:
-      itd.append(new EllipseItem(&aut));
+      it = new EllipseItem(&aut);
   }
+  if (index < 0)
+    itd.append(it);
+  else
+    itd.insert(index, it);
 }
 
 bool KplDoc::autoFile(double* xmi, double* xma, double* tic, int* mtic,
