@@ -7,7 +7,7 @@
 
     begin                : Sat Apr 24 15:14:00 MEST 1999
 
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -105,11 +105,12 @@ public:
    */
   const QDateTime& URLTime() const;
   /**
-   * Appends new item to list and initializes structure.
+   * Appends or inserts new item to list and initializes structure.
    * @param ityp type of item. One of the following:
    * Frame, Array, Function, ParFunction, Legend, Arrow.
+   * @param index index of item to insert before:
    */
-  void newItem(KplItem::ItemTypes ityp);
+  void newItem(KplItem::ItemTypes ityp, int index = -1);
   /**
    * Reads file and initializes plot items.
    * @param url URL of the file.
