@@ -2,7 +2,7 @@
                           kpldoubleedit.cpp  -  description
                              -------------------
     begin                : Tue Aug 15 2000
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -18,21 +18,21 @@
 #include "kpldoubleedit.h"
 #include <qvalidator.h>
 
-KplDoubleEdit::KplDoubleEdit(double val, QWidget* _parent,
-                             const char* format) :
- QLineEdit(_parent), frm(format)
+KplDoubleEdit::KplDoubleEdit(double val, QWidget* _parent, char format,
+                             int prc) :
+ QLineEdit(_parent), frm(format), prec(prc)
 {
   validator = new QDoubleValidator::QDoubleValidator(this);
-  validator->setDecimals(16);
+  validator->setDecimals(prc);
   setValidator(validator);
   setValue(val);
 }
 
 KplDoubleEdit::KplDoubleEdit(double val, double minVal, double maxVal,
-                             QWidget* _parent, const char* format) :
- QLineEdit(_parent), frm(format)
+                             QWidget* _parent, char format, int prc) :
+ QLineEdit(_parent), frm(format), prec(prc)
 {
-  validator = new QDoubleValidator::QDoubleValidator(minVal, maxVal, 16, this);
+  validator = new QDoubleValidator::QDoubleValidator(minVal, maxVal, prc, this);
   setValidator(validator);
   setValue(val);
 }
@@ -44,8 +44,7 @@ KplDoubleEdit::~KplDoubleEdit()
 
 double KplDoubleEdit::setValue(double val)
 {
-  QString s;
-  setText(s.sprintf(frm, val));
+  setText(QString::number(val, frm, prec));
   return value();
 }
 
@@ -55,7 +54,7 @@ double KplDoubleEdit::value()
   double val = s.toDouble();
   if (validator->bottom() || validator->top())
     val = QMAX(QMIN(val, validator->top()), validator->bottom());
-  setText(s.sprintf(frm, val));
+  setText(QString::number(val, frm, prec));
   return val;
 }
 
