@@ -2,7 +2,7 @@
                           kpldoubleedit.h  -  description
                              -------------------
     begin                : Tue Aug 15 2000
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -33,19 +33,21 @@ public:
    * Constructor.
    * @param val initial double value.
    * @param parent pointer to parent widget.
-   * @param format format string for value display.
+   * @param format format character for value display.
+   * @param prec precision (number of digits) for value display.
    */
-  KplDoubleEdit(double val, QWidget* parent, const char* format = "%.6lg");
+  KplDoubleEdit(double val, QWidget* parent, char format = 'g', int prec = 6);
   /**
    * Constructor.
    * @param val initial double value.
    * @param minVal minimum value.
    * @param maxVal maximum value.
    * @param parent pointer to parent widget.
-   * @param format format string for value display.
+   * @param format format character for value display.
+   * @param prec precision (number of digits) for value display.
    */
   KplDoubleEdit(double val, double minVal, double maxVal, QWidget* parent,
-                const char* format = "%.2lf");
+                char format = 'f', int prec = 2);
   /** Destructor. */
   ~KplDoubleEdit();
   /**
@@ -68,7 +70,8 @@ public:
 protected:
   /** Reimplemented for fixup of text. */
   virtual void focusOutEvent(QFocusEvent*);
-  QString frm;
+  char frm;
+  int prec;
   QDoubleValidator* validator;
 };
 
