@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Wed Aug 25 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -174,7 +174,7 @@ protected:
   QRect bRect;
 
   friend class ItemDlg;
-  friend KplDoc;
+  friend class KplDoc;
 };
 
 /**
@@ -234,7 +234,8 @@ protected:
   friend class FuncDlg;
   friend class ParFuncDlg;
   friend class ItemDlg;
-  friend KplDoc;
+  friend class KplDoc;
+  friend class KplView;
 };
 
 /**
