@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -42,7 +42,8 @@ public:
   /** Structure contains autoplot settings. */
   struct AutoStruct {
     bool autoErr, autoNorm, autohPath, autoFit, fitShowDlg, fitSavePar,
-         fitFollow, fitNonLin, showSource, autoLogX, autoLogY, addData;
+         fitFollow, fitNonLin, showSource, autoLogX, autoLogY, addData,
+         appendItems;
     bool fitPar[KPL_NPMAX];
     int prec, ixAuto, iyAuto, ieAuto, autoGrid, autoSymb, fitMaxIt, fitSymb,
         nyLeg, iSep;
