@@ -7,7 +7,7 @@
 
     begin                : Sat Apr 24 15:14:00 MEST 1999
 
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -20,12 +20,18 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qpaintdevicemetrics.h>
+#include <math.h>
+#include <stdlib.h>
 #include <qdragobject.h>
+#include <qpaintdevicemetrics.h>
 #include <qtimer.h>
-#include "kplview.h"
-#include "kpldoc.h"
+#include "frameitem.h"
+#include "funitem.h"
 #include "kpl.h"
+#include "kpldoc.h"
+#include "kplview.h"
+#include "splineitem.h"
+#include "utils.h"
 
 KplView::KplView(KplApp* _parent, double f) :
  KplWidget(_parent), fZoom(f), hPos(0.0), vPos(1.0)
@@ -162,8 +168,9 @@ void KplView::paintWidget()
 
 void KplView::setScrollBars()
 {
-  horizontalScrollBar()->setValue(hPos * horizontalScrollBar()->maxValue());
-  verticalScrollBar()->setValue(vPos * verticalScrollBar()->maxValue());
+  horizontalScrollBar()->setValue(int(hPos *
+                                      horizontalScrollBar()->maxValue()));
+  verticalScrollBar()->setValue(int(vPos * verticalScrollBar()->maxValue()));
 }
 
 void KplView::contentsMousePressEvent(QMouseEvent* e)
@@ -185,7 +192,9 @@ void KplView::contentsMousePressEvent(QMouseEvent* e)
           break;
         }
       }
-    }
+    } else
+      if (e->button() == MidButton)
+        startPos = dragPos = e->pos();
 }
 
 void KplView::contentsMouseReleaseEvent(QMouseEvent* e)
@@ -226,7 +235,72 @@ void KplView::contentsMouseReleaseEvent(QMouseEvent* e)
       }
       sel.clear();
     }
-  }
+  } else
+    if (e->button() == MidButton) {
+      QRect r = sortedRect(startPos, dragPos);
+      if (r.isValid()) {
+        FrameItem* it = 0;
+        KplItem* item;
+        for (item = doc->items()->last(); item;
+             item = doc->items()->prev()) {
+          if (item->iType() == KplItem::Frame &&
+              (item->boundingRect().contains(startPos) ||
+               item->boundingRect().contains(dragPos))) {
+            it = (FrameItem*) item;
+            break;
+          }
+        }
+        if (it) {
+          int mnx = minx0 + qRound(scalx * factor * it->x0);
+          int mny = miny0 + qRound(scaly * factor * it->y0);
+          double xmi = it->logx ? log10(it->xmi) : it->xmi;
+          double ymi = it->logy ? log10(it->ymi) : it->ymi;
+          double xsc = qRound(scalx * factor * it->w) /
+                       ((it->logx ? log10(it->xma) : it->xma) - xmi);
+          double ysc = qRound(scaly * factor * it->h) /
+                       ((it->logy ? log10(it->yma) : it->yma) - ymi);
+          double xMin = (r.left() - mnx) / xsc + xmi;
+          double xMax = (r.right() - mnx) / xsc + xmi;
+          if (it->logx) {
+            xMin = pow(10, xMin);
+            xMax = pow(10, xMax);
+          }
+          double yMin = (r.bottom() - mny) / ysc + ymi;
+          double yMax = (r.top() - mny) / ysc + ymi;
+          if (it->logy) {
+            yMin = pow(10, yMin);
+            yMax = pow(10, yMax);
+          }
+          Utils::autoSc(&it->xmi, &it->xma, &it->xtic, &it->mticx, &it->ndigx,
+                        xMin, xMax, 1.0, 0.2, it->logx);
+          Utils::autoSc(&it->ymi, &it->yma, &it->ytic, &it->mticy, &it->ndigy,
+                        yMin, yMax, 1.0, 0.2 * it->w / it->h, it->logy);
+          it->xOff = it->yOff = 0.0;
+          for (item = doc->items()->next(); item; item = doc->items()->next()) {
+            KplItem::ItemTypes typ = item->iType();
+            switch (typ) {
+              case KplItem::Function:
+                ((FunItem*) item)->tmin = it->xmi / ((FunItem*) item)->fx;
+                ((FunItem*) item)->tmax = it->xma / ((FunItem*) item)->fx;
+                ((FunItem*) item)->dt = 0.0;
+                break;
+              case KplItem::Spline:
+                ((SplineItem*) item)->xmin = it->xmi / ((SplineItem*) item)->fx;
+                ((SplineItem*) item)->xmax = it->xma / ((SplineItem*) item)->fx;
+                ((SplineItem*) item)->dx = 0.0;
+                break;
+              default:
+                break;
+            }
+            if (typ == KplItem::Frame)
+              break;
+          }
+          doc->setModified();
+          doc->backupItems();
+        } else
+          drawBoundingRect(r);
+      }
+    }
 }
 
 void KplView::contentsMouseMoveEvent(QMouseEvent* e)
@@ -248,7 +322,12 @@ void KplView::contentsMouseMoveEvent(QMouseEvent* e)
       emit mouseMoved(fromcm(d.x() / (scalx * factor) + it1->xPos(),
                              d.y() / (scaly * factor) + it1->yPos()), false);
     }
-  } else
+  } else {
+    if (e->state() & MidButton) {
+      drawBoundingRect(sortedRect(startPos, dragPos));
+      dragPos = e->pos();
+      drawBoundingRect(sortedRect(startPos, dragPos));
+    }
     if (QRect(contentsX(), contentsY(), visibleWidth(),
               visibleHeight()).contains(e->pos())) {
       bool showValues = false;
@@ -264,6 +343,7 @@ void KplView::contentsMouseMoveEvent(QMouseEvent* e)
       emit mouseMoved(e->pos(), showValues);
     } else
       emit mouseLeaved();
+  }
 }
 
 void KplView::contentsDragEnterEvent(QDragEnterEvent* e)
@@ -294,3 +374,9 @@ void KplView::drawBoundingRect(const QRect& r)
   end();
   repaintContents(0, 0, pm.width(), pm.height(), false);
 }
+
+QRect KplView::sortedRect(QPoint& p1, QPoint& p2)
+{
+  return QRect(QMIN(p1.x(), p2.x()), QMIN(p1.y(), p2.y()),
+               abs(p1.x() - p2.x()), abs(p1.y() - p2.y()));
+}
