@@ -7,7 +7,7 @@
 
     begin                : Sat Apr 24 15:14:00 MEST 1999
 
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -146,6 +146,13 @@ protected:
    * @param r rectangle
    */
   void drawBoundingRect(const QRect& r);
+  /**
+   * Constructs rectangle given by two points.
+   * @param p1 first point
+   * @param p2 second point
+   * @return rectangle.
+   */
+  QRect sortedRect(QPoint& p1, QPoint& p2);
   KplDoc* doc;
   QList<KplItem> sel;
   double fZoom, hPos, vPos;
