@@ -2,7 +2,7 @@
                           kplwidget.cpp  -  description
                              -------------------
     begin                : Mon Jul 16 2001
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -25,7 +25,6 @@
 
 KplWidget::KplWidget(QWidget* parent) : QScrollView(parent)
 {
-//  QScrollView::viewport()->setBackgroundMode(PaletteBase);
 }
 
 KplWidget::KplWidget(QWidget* parent, QList<KplItem>* items, int w, int h,
@@ -65,7 +64,7 @@ void KplWidget::print(QPrinter* printer, QList<KplItem>* items)
 
 QSize KplWidget::sizeHint() const
 {
-  return QScrollView::sizeHint() + QSize(1, 1);
+  return QSize(contentsWidth() + 5, contentsHeight() + 5);
 }
 
 void KplWidget::drawContents(QPainter*, int clipx, int clipy, int clipw,
