@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -24,7 +24,6 @@
 #include <qlabel.h>
 #include <qlayout.h>
 #include <klocale.h>
-#include <kapp.h>
 #include <kcolorbtn.h>
 #include "kplspinbox.h"
 #include "legenddlg.h"
@@ -83,11 +82,7 @@ LegendDlg::LegendDlg(QWidget* _parent, KplDoc* model, LegendItem* ld0) :
   grid->addWidget(new QLabel("yoff", g), 2, 4);
   grid->addWidget(eyl = new KplDoubleEdit(ld->ytext, -200.0, 200.0, g), 2, 5);
   grid->addWidget(new QLabel("cm", g), 2, 6);
-#if KDE_VERSION == 303
-  connect(this, SIGNAL(helpClicked()), SLOT(slotHelp2()));
-#else
   setHelp("SEC-LEGEND");
-#endif
   resize(minimumSize());
 }
 
@@ -127,11 +122,3 @@ void LegendDlg::slotApply()
 {
   getValues(false);
 }
-
-void LegendDlg::slotHelp2()
-{
-#if KDE_VERSION == 303
-  kapp->startServiceByDesktopName("konqueror", QString("help:/kpl/legend.html"),
-                                  0, 0, 0, "", true);
-#endif
-}
