@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Tue Aug 31 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -102,9 +102,8 @@ void LegendItem::draw(KplGraph* g)
     }
     double sav = g->setRelSize(relsiz);
     g->setRelSize(sav * symbSize);
-    g->plArray(xa, ya, 1.0, 1.0, n);
-    if (symb > 0)
-      g->resetDash();
+    g->plArray(xa, ya, 1.0, 1.0, n, false);
+    g->resetDash();
     g->setColFrame(coltext);
     g->setRelSize(relsiz);
     g->textcm(s, x0 + xtext, y0 + ytext, 1, g->type() ? 0 : &bRect);
