@@ -2,7 +2,7 @@
                           linedlg.cpp  -  description
                              -------------------
     begin                : Mon Apr 16 2001
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -18,7 +18,6 @@
 #include <qlayout.h>
 #include <qlabel.h>
 #include <klocale.h>
-#include <kapp.h>
 #include "kpldoubleedit.h"
 #include "kplspinbox.h"
 #include "lineitem.h"
@@ -39,9 +38,6 @@ LineDlg::LineDlg(QWidget* _parent, KplDoc* model, LineItem* ld0) :
   SymbolButton* bSymb = new SymbolButton(frame, symb, true);
   grid->addWidget(bSymb, 3, 2);
   bSymb->setFixedWidth(50);
-#if KDE_VERSION == 303
-  connect(this, SIGNAL(helpClicked()), SLOT(slotHelp2()));
-#endif
 }
 
 LineDlg::~LineDlg()
@@ -65,11 +61,3 @@ void LineDlg::slotApply()
 {
   getValues(false);
 }
-
-void LineDlg::slotHelp2()
-{
-#if KDE_VERSION == 303
-  kapp->startServiceByDesktopName("konqueror", QString("help:/kpl/line.html"),
-                                  0, 0, 0, "", true);
-#endif
-}
