@@ -2,7 +2,7 @@
                           linedlg.h  -  description
                              -------------------
     begin                : Mon Apr 16 2001
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -56,8 +56,6 @@ protected slots:
   virtual void slotOk();
   /** Applies settings without leaving the dialog. */
   virtual void slotApply();
-  /** Displays help for the line settings dialog. */
-  void slotHelp2();
 };
 
 #endif
