@@ -7,7 +7,7 @@
 
     begin                : Sat Apr 24 15:14:00 MEST 1999
 
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -21,9 +21,9 @@
  ***************************************************************************/
 
 #include <dcopclient.h>
+#include <kaboutdata.h>
 #include <kapp.h>
 #include <kcmdlineargs.h>
-#include <kaboutdata.h>
 #include <klocale.h>
 #include "kpl.h"
 
@@ -35,20 +35,19 @@ static KCmdLineOptions options[] = {
   {0, 0, 0}
 };
 
-int main(int argc, char* argv[])
+int main(int argc, char** argv)
 {
   KAboutData aboutData("kpl", I18N_NOOP("Kpl"), VERSION, description,
-                       KAboutData::License_GPL, "(c) 2002, Werner Stille",
+                       KAboutData::License_GPL, "(c) 2003, Werner Stille",
                        0, 0, "stille@uni-freiburg.de");
   aboutData.addAuthor("Werner Stille", 0, "stille@uni-freiburg.de");
   KCmdLineArgs::init(argc, argv, &aboutData);
   KCmdLineArgs::addCmdLineOptions(options);
   KApplication app;
-  DCOPClient* client = kapp->dcopClient();
-  client->registerAs(kapp->name(), false);
-  if (app.isRestored()) {
-    RESTORE(KplApp);
-  } else {
+  app.dcopClient()->registerAs(app.name(), false);
+  if (app.isRestored())
+    RESTORE(KplApp)
+  else {
     KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
     KplApp* kpl = new KplApp;
     if (args->count()) {
