@@ -2,7 +2,7 @@
                           rectdlg.cpp  -  description
                              -------------------
     begin                : Sat Apr 28 2001
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -19,7 +19,6 @@
 #include <qlabel.h>
 #include <qcheckbox.h>
 #include <klocale.h>
-#include <kapp.h>
 #include "kpldoubleedit.h"
 #include "rectitem.h"
 #include "rectdlg.h"
@@ -45,9 +44,6 @@ RectDlg::RectDlg(QWidget* _parent, KplDoc* model, RectItem* rd0) :
   lSize->setText(i18n("Line width"));
   grid->addWidget(fill = new QCheckBox(i18n("Filled"), frame), 4, 5);
   fill->setChecked(rd->filled);
-#if KDE_VERSION == 303
-  connect(this, SIGNAL(helpClicked()), SLOT(slotHelp2()));
-#endif
 }
 
 RectDlg::~RectDlg()
@@ -72,13 +68,3 @@ void RectDlg::slotApply()
 {
   getValues(false);
 }
-
-void RectDlg::slotHelp2()
-{
-#if KDE_VERSION == 303
-  kapp->startServiceByDesktopName("konqueror",
-    QString(rd->iType() == KplItem::Rectangle ? "help:/kpl/rect.html" :
-                                                "help:/kpl/ellipse.html"),
-    0, 0, 0, "", true);
-#endif
-}
