@@ -2,7 +2,7 @@
                           textdlg.cpp  -  description
                              -------------------
     begin                : Wed Apr 18 2001
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -21,7 +21,6 @@
 #include <qpushbutton.h>
 #include <qstringlist.h>
 #include <klocale.h>
-#include <kapp.h>
 #include "edittextdlg.h"
 #include "kpldoubleedit.h"
 #include "textitem.h"
@@ -48,9 +47,6 @@ TextDlg::TextDlg(QWidget* _parent, KplDoc* model, TextItem* td0) :
   eAlign->insertStringList(list);
   eAlign->setCurrentItem(td->iAlign - 1);
   initEntries(2);
-#if KDE_VERSION == 303
-  connect(this, SIGNAL(helpClicked()), SLOT(slotHelp2()));
-#endif
 }
 
 TextDlg::~TextDlg()
@@ -80,11 +76,3 @@ void TextDlg::slotApply()
 {
   getValues(false);
 }
-
-void TextDlg::slotHelp2()
-{
-#if KDE_VERSION == 303
-  kapp->startServiceByDesktopName("konqueror", QString("help:/kpl/text.html"),
-                                  0, 0, 0, "", true);
-#endif
-}
