@@ -2,7 +2,7 @@
                           textdlg.h  -  description
                              -------------------
     begin                : Wed Apr 18 2001
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -61,8 +61,6 @@ protected slots:
   virtual void slotOk();
   /** Applies settings without leaving the dialog. */
   virtual void slotApply();
-  /** Displays help for the text settings dialog. */
-  void slotHelp2();
 };
 
 #endif
