@@ -2,7 +2,7 @@
                           threeddlg.cpp  -  description
                              -------------------
     begin                : Thu Apr 25 2002
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -16,7 +16,6 @@
  ***************************************************************************/
 
 #include <math.h>
-#include <dlfcn.h>
 #include <qlayout.h>
 #include <qgroupbox.h>
 #include <qlabel.h>
@@ -26,7 +25,7 @@
 #include <qcheckbox.h>
 #include <qfile.h>
 #include <kapp.h>
-#if (KDE_VERSION_MAJOR < 3) || (KDE_VERSION_MINOR < 9)
+#if KDE_VERSION_MAJOR < 3
 #include <qmultilineedit.h>
 #endif
 #include <klocale.h>
@@ -52,9 +51,7 @@ ThreeDDlg::ThreeDDlg(QWidget* _parent, KplDoc* model, ThreeDItem *td0,
  KDialogBase(Tabbed, caption, Help | Ok | Apply | Cancel | User1, Ok, _parent,
              0, true, true, i18n("&Export")), m(model), td(td0)
 {
-#if KDE_VERSION != 303
   setHelp(anchor);
-#endif
   frame1 = addPage(page1);
   vbox1 = new QVBoxLayout(frame1, marginHint(), spacingHint());
   g1 = new QGroupBox(0, Qt::Vertical, i18n("Range"), frame1);
@@ -233,23 +230,29 @@ ThreeDDlg::~ThreeDDlg()
 
 void ThreeDDlg::initRange(QGridLayout* grid, int row)
 {
+  char frm = m->options()->format;
+  int prec = m->options()->prec;
   grid->addWidget(new QLabel("xmin", g1), row, 0);
-  grid->addWidget(exMin = new KplDoubleEdit(td->xmi, g1), row, 1);
+  grid->addWidget(exMin = new KplDoubleEdit(td->xmi, g1, frm, prec), row, 1);
+  int w = exMin->fontMetrics().width(m->number(-1.0e-123 / 3.0)) + 3;
+  exMin->setMinimumWidth(w);
   grid->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding), row, 2);
   grid->addWidget(new QLabel("xmax", g1), row, 3);
-  grid->addWidget(exMax = new KplDoubleEdit(td->xma, g1), row, 4);
+  grid->addWidget(exMax = new KplDoubleEdit(td->xma, g1, frm, prec), row, 4);
+  exMax->setMinimumWidth(w);
   grid->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding), row, 5);
   QHBoxLayout* hbox = new QHBoxLayout(1);
   grid->addLayout(hbox, row, 6);
   QLabel* l = new QLabel("D", g1);
-#if (KDE_VERSION_MAJOR > 2) || (KDE_VERSION_MINOR > 8)
+#if KDE_VERSION_MAJOR > 2
   l->setFont(QFont("Symbol", 12, QFont::Normal, false));
 #else
   l->setFont(QFont("Symbol", 12, QFont::Normal, false, QFont::AnyCharSet));
 #endif
   hbox->addWidget(l);
   hbox->addWidget(new QLabel("x", g1));
-  grid->addWidget(exStep = new KplDoubleEdit(td->dx, g1), row, 7);
+  grid->addWidget(exStep = new KplDoubleEdit(td->dx, g1, frm, prec), row, 7);
+  exStep->setMinimumWidth(w);
   grid->addItem(new QSpacerItem(20, 10, QSizePolicy::MinimumExpanding), row, 8);
   grid->addWidget(logX = new QCheckBox("log", g1), row++, 9);
   logX->setChecked(td->logx);
@@ -260,19 +263,22 @@ void ThreeDDlg::initRange(QGridLayout* grid, int row)
   grid->addWidget(logY = new QCheckBox("log", g1), row++, 9);
   logY->setChecked(td->logy);
   grid->addWidget(new QLabel("zmin", g1), row, 0);
-  grid->addWidget(ezMin = new KplDoubleEdit(td->zmi, g1), row, 1);
+  grid->addWidget(ezMin = new KplDoubleEdit(td->zmi, g1, frm, prec), row, 1);
+  ezMin->setMinimumWidth(w);
   grid->addWidget(new QLabel("zmax", g1), row, 3);
-  grid->addWidget(ezMax = new KplDoubleEdit(td->zma, g1), row, 4);
+  grid->addWidget(ezMax = new KplDoubleEdit(td->zma, g1, frm, prec), row, 4);
+  ezMax->setMinimumWidth(w);
   grid->addLayout(hbox = new QHBoxLayout(1), row, 6);
   l = new QLabel("D", g1);
-#if (KDE_VERSION_MAJOR > 2) || (KDE_VERSION_MINOR > 8)
+#if KDE_VERSION_MAJOR > 2
   l->setFont(QFont("Symbol", 12, QFont::Normal, false));
 #else
   l->setFont(QFont("Symbol", 12, QFont::Normal, false, QFont::AnyCharSet));
 #endif
   hbox->addWidget(l);
   hbox->addWidget(new QLabel("z", g1));
-  grid->addWidget(ezStep = new KplDoubleEdit(td->dz, g1), row, 7);
+  grid->addWidget(ezStep = new KplDoubleEdit(td->dz, g1, frm, prec), row, 7);
+  ezStep->setMinimumWidth(w);
   grid->addWidget(logZ = new QCheckBox("log", g1), row, 9);
   logZ->setChecked(td->logz);
   connect(logX, SIGNAL(toggled(bool)), SLOT(slotLogToggled(bool)));
@@ -490,9 +496,6 @@ Fun3DDlg::Fun3DDlg(QWidget* _parent, KplDoc* model, Fun3DItem *fd0) :
   connect(b, SIGNAL(clicked()), SLOT(slotSaveParameter()));
   vbox1->addWidget(g1);
   initRange(new QGridLayout(g1->layout(), 3, 10, spacingHint()));
-#if KDE_VERSION == 303
-  connect(this, SIGNAL(helpClicked()), SLOT(slotHelp2()));
-#endif
   Utils::setSize(this, "Func3DDialog");
 }
 
@@ -507,7 +510,7 @@ bool Fun3DDlg::getTemp()
   fdt->pathy = fileName->text();
   fdt->namey = func->text();
   if (fdt->hmody)
-    dlclose(fdt->hmody);
+    lt_dlclose(fdt->hmody);
   if (Fun3DItem::getFunc3DAddr(fdt->pathy.path(), fdt->namey, &fdt->hmody,
                            &fdt->fkty))
     return false;
@@ -535,7 +538,7 @@ void Fun3DDlg::slotFile()
 
 void Fun3DDlg::slotFunc()
 {
-  FuncDlg::getFunc(this, fileName, func);
+  FuncDlg::getFunc(this, fileName, func, true);
 }
 
 void Fun3DDlg::slotGetParameter()
@@ -545,7 +548,8 @@ void Fun3DDlg::slotGetParameter()
 
 void Fun3DDlg::slotEditParameter()
 {
-  EditParameterDlg dlg(this, m, fdt->py, fileName->text(), func->text(), true);
+  EditParameterDlg dlg(this, m, fdt->py, fileName->text(), func->text(), true,
+                       true);
   connect(&dlg, SIGNAL(applyClicked()), SLOT(slotApply()));
   dlg.exec();
 }
@@ -617,15 +621,6 @@ void Fun3DDlg::slotUser1()
   }
 }
 
-void Fun3DDlg::slotHelp2()
-{
-#if KDE_VERSION == 303
-  kapp->startServiceByDesktopName("konqueror",
-                                  QString("help:/kpl/func3d.html"),
-                                  0, 0, 0, "", true);
-#endif
-}
-
 Array3DDlg::Array3DDlg(QWidget* _parent, KplDoc* model, Array3DItem *ad0) :
  ThreeDDlg(_parent, model, ad0, i18n("3D array"), "SEC-ARRAY3D",
            i18n("Array")), ad(ad0), adt(0)
@@ -684,9 +679,6 @@ Array3DDlg::Array3DDlg(QWidget* _parent, KplDoc* model, Array3DItem *ad0) :
   grid->addWidget(n = new KplSpinBox(0, 0, 1, g1), 0, 4);
   setSpinBoxes(ad);
   initRange(grid, 1);
-#if KDE_VERSION == 303
-  connect(this, SIGNAL(helpClicked()), SLOT(slotHelp2()));
-#endif
   connect(internal, SIGNAL(toggled(bool)), SLOT(slotInternal(bool)));
   connect(err, SIGNAL(toggled(bool)), ie, SLOT(setEnabled(bool)));
   connect(iStart, SIGNAL(valueChanged(int)), SLOT(slotStartChanged(int)));
@@ -899,7 +891,7 @@ void Array3DDlg::slotEdit()
     for (int j = 0; j < src->ncols; j++)
       t << m->number(src->xv[j][i])
         << (j < (src->ncols - 1) ? m->separator() : QString("\n"));
-#if (KDE_VERSION_MAJOR > 2) || (KDE_VERSION_MINOR > 8)
+#if KDE_VERSION_MAJOR > 2
   EditDlg dlg(this, &buf, m->options()->prec + 4);
 #else
   int sav = QMultiLineEdit::defaultTabStop();
@@ -912,7 +904,7 @@ void Array3DDlg::slotEdit()
     adt = new Array3DItem;
     readData(true);
   }
-#if (KDE_VERSION_MAJOR < 3) && (KDE_VERSION_MINOR < 9)
+#if KDE_VERSION_MAJOR < 3
   QMultiLineEdit::setDefaultTabStop(sav);
 #endif
 }
@@ -985,12 +977,3 @@ void Array3DDlg::slotUser1()
     }
   }
 }
-
-void Array3DDlg::slotHelp2()
-{
-#if KDE_VERSION == 303
-  kapp->startServiceByDesktopName("konqueror",
-                                  QString("help:/kpl/array3d.html"),
-                                  0, 0, 0, "", true);
-#endif
-}
