@@ -2,7 +2,7 @@
                           threeditem.cpp  -  description
                              -------------------
     begin                : Tue Dec 25 2001
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -18,7 +18,6 @@
 #include <stdlib.h>
 #include <float.h>
 #include <math.h>
-#include <dlfcn.h>
 #include <qurl.h>
 #include <qfileinfo.h>
 #include <ksimpleconfig.h>
@@ -791,6 +790,7 @@ Fun3DItem::Fun3DItem() : fkty(0), fktyo(0), hmody(0)
 Fun3DItem::Fun3DItem(const Fun3DItem& f) : ThreeDItem(f), fkty(f.fkty),
  fktyo(f.fktyo), namey(f.namey), pathy(f.pathy), hmody(f.hmody)
 {
+  lt_dlinit();
   memcpy(py, f.py, sizeof(py));
   memcpy(pyo, f.pyo, sizeof(pyo));
   if (f.hmody)
@@ -806,6 +806,7 @@ Fun3DItem::Fun3DItem(Kpl::AutoStruct* aut) : ThreeDItem(aut), fkty(0), fktyo(0),
 Fun3DItem::Fun3DItem(KSimpleConfig* plo, Kpl::AutoStruct* aut,
                      const KURL& uPlo) : ThreeDItem(plo, aut), fktyo(0)
 {
+  lt_dlinit();
   memset(pyo, 0, sizeof(pyo));
   QStringList list = plo->readListEntry("p", ' ');
   int cnt = list.count();
@@ -844,7 +845,8 @@ Fun3DItem::Fun3DItem(bool act, bool lgx, bool lgy, bool lgz, bool frame,
 Fun3DItem::~Fun3DItem()
 {
   if (hmody)
-    dlclose(hmody);
+    lt_dlclose(hmody);
+  lt_dlexit();
 }
 
 Fun3DItem& Fun3DItem::operator=(const Fun3DItem& f)
@@ -858,7 +860,7 @@ Fun3DItem& Fun3DItem::operator=(const Fun3DItem& f)
     namey = f.namey;
     pathy = f.pathy;
     if (hmody)
-      dlclose(hmody);
+      lt_dlclose(hmody);
     hmody = 0;
     if (f.hmody)
       getFunc3DAddr(pathy.path(), namey, &hmody, &fkty);
@@ -884,6 +886,14 @@ void Fun3DItem::writePlo(KSimpleConfig* plo, const KURL& url, bool _abs,
 {
   ThreeDItem::writePlo(plo, url, _abs, m);
   plo->writeEntry("Type", "FUN3DITEM");
+  char frm = m->options()->format;
+  int prec = m->options()->prec;
+  plo->writeEntry("xmi", xmi, true, false, frm, prec);
+  plo->writeEntry("xma", xma, true, false, frm, prec);
+  plo->writeEntry("zmi", zmi, true, false, frm, prec);
+  plo->writeEntry("zma", zma, true, false, frm, prec);
+  plo->writeEntry("dx", dx, true, false, frm, prec);
+  plo->writeEntry("dz", dz, true, false, frm, prec);
   QStrList list;
   for (int i = 0; i < KPL_NPMAX; i++)
     list.insert(i, m->number(py[i]));
@@ -922,34 +932,31 @@ void Fun3DItem::exportTable(QTextStream& ts, KplDoc* m) const
 }
 
 bool Fun3DItem::getFunc3DAddr(const QString& path, const QString& name,
-                              void** hmod,
+                              lt_dlhandle* hmod,
                               double (**fkt)(double, double, const double*))
 {
   *hmod = 0;
   *fkt = 0;
-  if (path.isEmpty() || name.isEmpty()) {
+  if (path.isEmpty() || name.isEmpty())
     KMessageBox::sorry(0, i18n("no library or no function specified!"));
-    return true;
-  }
-  if (!(*hmod = dlopen(path, RTLD_NOW))) {
-    KMessageBox::error(0, i18n("while trying to open") + "\n" + path +
-                       "\n" + dlerror());
-    return true;
-  } else {
-    *fkt = (double (*)(double, double, const double *)) dlsym(*hmod, name);
-    if (const char* error = dlerror()) {
-      KMessageBox::error(0, i18n("while trying to determine the address of") +
-                         "\n" + name + "\n" + error);
-      dlclose(*hmod);
-      *hmod = 0;
-      return true;
-    } else
-      return false;
-  }
+  else
+    if (!(*hmod = lt_dlopen(path)))
+      KMessageBox::error(0, lt_dlerror());
+    else
+      if ((*fkt = (double (*)(double, double, const double *))
+                  lt_dlsym(*hmod, name)))
+        return false;
+      else {
+        KMessageBox::error(0, lt_dlerror());
+        lt_dlclose(*hmod);
+        *hmod = 0;
+      }
+  return true;
 }
 
 void Fun3DItem::init()
 {
+  lt_dlinit();
   memset(py, 0, sizeof(py));
   memset(pyo, 0, sizeof(pyo));
 }
