@@ -2,7 +2,7 @@
                           threeditem.h  -  description
                              -------------------
     begin                : Tue Dec 25 2001
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -18,6 +18,7 @@
 #ifndef THREEDITEM_H
 #define THREEDITEM_H
 
+#include "ltdl.h"
 #include "frameitem.h"
 
 /**
@@ -341,7 +342,7 @@ public:
    * @param fkt pointer to function address.
    */
   static bool getFunc3DAddr(const QString& path, const QString& name,
-                            void** hmod,
+                            lt_dlhandle* hmod,
                             double (**fkt)(double, double, const double*));
 
 protected:
@@ -359,7 +360,7 @@ protected:
   mutable double pyo[20];
   QString namey;
   KURL pathy;
-  void* hmody;
+  lt_dlhandle hmody;
 
   friend class Fun3DDlg;
   friend class KplApp;
