@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -20,7 +20,6 @@
  ***************************************************************************/
 
 #include <math.h>
-#include <dlfcn.h>
 #include <qlineedit.h>
 #include <qmultilinedit.h>
 #include <qfileinfo.h>
@@ -30,28 +29,52 @@
 #include <qgroupbox.h>
 #include <qlayout.h>
 #include <qtimer.h>
+#include <qregexp.h>
 #include <klocale.h>
 #include <kfiledialog.h>
 #include <kmessagebox.h>
 #include <kio/netaccess.h>
 #include <kglobal.h>
 #include <kurl.h>
+#include <kapp.h>
 #include "kpldoc.h"
 #include "utils.h"
 #include "sourcewidget.h"
+#include "kpldoubleedit.h"
 
-ChooseFuncDlg::ChooseFuncDlg(QWidget* _parent, QFile* f, QLineEdit* func0) :
+ChooseFuncDlg::ChooseFuncDlg(QWidget* _parent, QFile* f, QLineEdit* func0,
+                             bool d3) :
  KDialogBase(Plain, QString::null, Ok | Cancel, Ok, _parent), func(func0)
 {
   setPlainCaption(i18n("Functions"));
   QFrame* frame = plainPage();
   QVBoxLayout* vbox = new QVBoxLayout(frame, 0, spacingHint());
   vbox->addWidget(funcList = new QListBox(frame));
+#if KDE_VERSION_MAJOR > 2
+  QRegExp rx2("\\S+__");
+  QRegExp rx2a(d3 ? "\\S+__FddPCd" : "\\S+__FdPCd");
+  QRegExp rx3("_\\S+");
+  QRegExp rx3a(d3 ? "_Z\\d+\\S+ddPKd" : "_Z\\d+\\S+dPKd");
+#else
+  QRegExp rx2("[^\\s]+__");
+  QRegExp rx2a(d3 ? "[^\\s]+__FddPCd" : "[^\\s]+__FdPCd");
+  QRegExp rx3("_[^\\s]+");
+  QRegExp rx3a(d3 ? "_Z\\d+[^\\s]+ddPKd" : "_Z\\d+[^\\s]+dPKd");
+#endif
   QTextStream t(f);
   while (!t.eof()) {
     QString line = t.readLine();
-    if (line[9] == 'T')
-      funcList->insertItem(line.mid(11));
+    if (line[9] == 'T') {
+      QString s = line.mid(11);
+#if KDE_VERSION_MAJOR > 2
+      if ((rx2.search(s) && rx3.search(s)) || (!rx2a.search(s)) ||
+          (!rx3a.search(s)))
+#else
+      if ((rx2.find(s, 0) && rx3.find(s, 0)) || (!rx2a.find(s, 0)) ||
+          (!rx3a.find(s, 0)))
+#endif
+        funcList->insertItem(s);
+    }
   }
   f->close();
   connect(funcList, SIGNAL(selected(int)), SLOT(slotList(int)));
@@ -79,7 +102,7 @@ void ChooseFuncDlg::slotOk()
 
 EditParameterDlg::EditParameterDlg(QWidget* _parent, KplDoc* m, double* p0,
                                    const QString& file, const QString& func,
-                                   bool applyButton) :
+                                   bool applyButton, bool d3) :
  KDialogBase(Plain, i18n("Parameters"),
              applyButton ? Ok | Cancel | Apply : Ok | Cancel,
              Ok, _parent, 0, true, true), p(p0)
@@ -98,29 +121,61 @@ EditParameterDlg::EditParameterDlg(QWidget* _parent, KplDoc* m, double* p0,
                                       spacingHint());
   vbox->addWidget(g);
   QString s;
+  char frm = m->options()->format;
+  int prec = m->options()->prec;
+  int w = 0;
   for (int i = 0; i < KPL_NPMAX; i++) {
     int ix = 3 * (i / 10);
     int iy = i % 10;
     grid->addWidget(new QLabel(s.sprintf("p%i", i), g), iy, ix);
-    grid->addWidget(par[i] = new QLineEdit(m->number(p[i]), g), iy, ix + 1);
-    par[i]->setMaximumWidth(80);
+    grid->addWidget(par[i] = new KplDoubleEdit(p[i], g, frm, prec), iy,
+                    ix + 1);
+    if (!i)
+      w = par[0]->fontMetrics().width(m->number(-1.0e-123 / 3.0)) + 3;
+    par[i]->setMinimumWidth(w);
   }
   for (int i = 0; i < ((KPL_NPMAX - 1) / 10); i++)
     grid->addItem(new QSpacerItem(20, 10), 0, 3 * i + 2);
   if (m->options()->showSource) {
     QFileInfo fi(file);
-    int pp = func.find("__");
-    s = fi.dirPath(true) + "/" + fi.baseName() + ((pp != -1) ? ".cpp" : ".c");
-    QFile f(s);
-    if (f.open(IO_ReadOnly)) {
+#if KDE_VERSION_MAJOR > 2
+    QRegExp rx2(d3 ? "\\S+__FddPCd" : "\\S+__FdPCd");
+    QRegExp rx3(d3 ? "_Z\\d+\\S+ddPKd" : "_Z\\d+\\S+dPKd");
+    int pp2 = rx2.search(func);
+    int pp3 = rx3.search(func);
+#else
+    QRegExp rx2(d3 ? "[^\\s]+__FddPCd" : "[^\\s]+__FdPCd");
+    QRegExp rx3(d3 ? "_Z\\d+[^\\s]+ddPKd" : "_Z\\d+[^\\s]+dPKd");
+    int l2, l3;
+    int pp2 = rx2.match(func, 0, &l2);
+    int pp3 = rx3.match(func, 0, &l3);
+#endif
+    s = fi.dirPath(true) + "/" + fi.baseName();
+    bool guessC = pp2 && pp3;
+    QFile f(s + (guessC ? ".c" : ".cpp"));
+    bool open = f.open(IO_ReadOnly);
+    if (!open) {
+      f.setName(s + (guessC ? ".cpp" : ".c"));
+      open = f.open(IO_ReadOnly);
+    }
+    if (open) {
       SourceWidget* sw = new SourceWidget(frame, &f);
       hbox->addWidget(sw, 1);
       sw->setMinimumWidth(400);
-      if (pp != -1) {
-        s = func;
-        sw->highlight(s.left(pp));
-      } else
-        sw->highlight(func);
+      if (!pp2)
+#if KDE_VERSION_MAJOR > 2
+        sw->highlight(func.left(rx2.matchedLength() - 7));
+      else
+        if (!pp3)
+          sw->highlight(func.mid(3, rx3.matchedLength() - 7));
+#else
+        sw->highlight(func.left(l2 - 7));
+      else
+        if (!pp3)
+          sw->highlight(func.mid(3, l3 - 7));
+#endif
+        else
+          sw->highlight(func);
       QTimer::singleShot(0, sw, SLOT(slotHighlight()));
     }
   }
@@ -132,18 +187,8 @@ EditParameterDlg::~EditParameterDlg()
 
 void EditParameterDlg::getValues(bool ok)
 {
-  bool valid = true;
-  QString s;
-  double pt[KPL_NPMAX];
-  for (int i = 0; i < KPL_NPMAX; i++) {
-    s = par[i]->text();
-    pt[i] = s.toDouble(&valid);
-    if (!valid) {
-      KMessageBox::sorry(this, s.sprintf(i18n("invalid parameter %i"), i));
-      return;
-    }
-  }
-  memcpy(p, pt, KPL_NPMAX * sizeof(double));
+  for (int i = 0; i < KPL_NPMAX; i++)
+    p[i] = par[i]->value();
   if (ok)
     accept();
   else
@@ -409,14 +454,15 @@ QString Utils::relPath(const KURL& uPlo, const KURL& path, bool abs)
           return path.url();
       }
       QString dPlo = uPlo.directory(false);
+      u.cleanPath();
       QString dFile = u.directory(false);
-      int nMax = QMIN(dPlo.length(), dFile.length());
+      int nMax = QMIN(dPlo.length(), dFile.length()) - 1;
       int n;
       for (n = 0; n < nMax; n++)
         if (dPlo[n] != dFile[n])
           break;
       if (n > 0)
-        n = dFile.findRev('/', n) + 1;
+        n = dFile.findRev('/', n - 1) + 1;
       QString s = u.path().mid(n);
       int nUp = dPlo.contains('/') - dPlo.left(n).contains('/');
       for (int i = 0; i < nUp; i++)
