@@ -6,7 +6,7 @@
     data sets and functions.
 
     begin                : Sun Apr 25 1999
-    copyright            : (C) 2002 by Werner Stille
+    copyright            : (C) 2003 by Werner Stille
     email                : stille@uni-freiburg.de
  ***************************************************************************/
 
@@ -32,6 +32,7 @@ class QListBox;
 class QFile;
 class KURL;
 class KplDoc;
+class KplDoubleEdit;
 
 /**
   * Choose function dialog class. Provides a dialog for the selection
@@ -48,8 +49,9 @@ public:
    * @param f pointer to QFile opened for input from a file containing
    * a list of functions obtained using nm.
    * @param func pointer to QLineEdit widget for the function name.
+   * @param d3 true in case of a 3D function.
    */
-  ChooseFuncDlg(QWidget* parent, QFile* f, QLineEdit* func);
+  ChooseFuncDlg(QWidget* parent, QFile* f, QLineEdit* func, bool d3 = false);
   /** Destructor. */
   ~ChooseFuncDlg();
 
@@ -83,9 +85,12 @@ public:
    * @param p parameter array.
    * @param file absolute path of the function library.
    * @param func function name.
+   * @param applyButton true to show a button for applying.
+   * @param d3 true in case of a 3D function.
    */
   EditParameterDlg(QWidget* parent, KplDoc* m, double* p, const QString& file,
-                   const QString& func, bool applyButton = false);
+                   const QString& func, bool applyButton = false,
+                   bool d3 = false);
   /** Destructor. */
   ~EditParameterDlg();
 
@@ -96,7 +101,7 @@ protected:
    */
   void getValues(bool accept);
   double* p;
-  QLineEdit* par[KPL_NPMAX];
+  KplDoubleEdit* par[KPL_NPMAX];
 
 protected slots:
   /** Accepts changes and leaves the dialog. */
